
import java.applet.*;
import java.awt.*;
import java.awt.event.*;
import java.awt.image.*;
import java.io.*;
import java.net.*;

public class Comeback64 extends Applet implements WindowListener, Runnable, ImageObserver, MouseListener, MouseMotionListener, KeyListener, ActionListener
{
	private final int palette[] = { 0xFF000000, 0xFFFFFFFF, 0xFFAD524A, 0xFF73F7F7, 0xFFBD6BBD, 0xFF73E773, 0xFF4242C6, 0xFFFFFF7B, 0xFFC88E2F, 0xFF846339, 0xFFFF9C9C, 0xFF7B7B7B, 0xFF949494, 0xFFA5FFA5, 0xFF9C9CF7, 0xFFCECECE };

	private Frame frame = null;

	private Thread thread;
	private boolean initialized = false;

	private int pixelBuffer[] = new int[ 320 * 200 ];
	private Image bufferImage;

	private boolean bufferDragged = false;
	private int dragOriginX, dragOriginY, dragCurrentX, dragCurrentY;

	private int scale = 1;
	private int bufferX = 0;
	private int bufferY = 0;
	private boolean drawBorders = true;

	private boolean loadDialog = false;

	public static void main( String args[] )
	{
		Comeback64 cb64 = new Comeback64();

		cb64.frame = new Frame( "Comeback 64" );
		cb64.frame.addWindowListener( cb64 );

		MenuBar menuBar = new MenuBar();
		cb64.frame.setMenuBar( menuBar );
		Menu fileMenu = new Menu( "File" );
		menuBar.add( fileMenu );
		fileMenu.addActionListener( cb64 );
		fileMenu.add( "Load PRG..." );

		cb64.frame.add( cb64 );
		cb64.frame.pack();
		cb64.frame.show();
	}

	public Dimension getPreferredSize()
	{
		return new Dimension( 320, 200 );
	}

	public void windowActivated( WindowEvent event ){ requestFocus(); }
	public void windowClosed( WindowEvent event ){ System.exit( 0 ); }
	public void windowClosing( WindowEvent event ){ frame.dispose(); }
	public void windowDeactivated( WindowEvent event ){}
	public void windowDeiconified( WindowEvent event ){}
	public void windowIconified( WindowEvent event ){}
	public void windowOpened( WindowEvent event ){ start(); }

	public void init()
	{
		try
		{
			int i = Integer.parseInt( getParameter( "scale" ) );
			if( ( i > 0 ) && ( i < 20 ) ) scale = i;
		}
		catch( Exception e ){}

		try{ bufferX = Integer.parseInt( getParameter( "left" ) ); }
		catch( Exception e ){}

		try{ bufferY = Integer.parseInt( getParameter( "top" ) ); }
		catch( Exception e ){}
	}

	public void start()
	{
		thread = new Thread( this );
		thread.start();
	}

	public void stop()
	{
		thread.stop();
	}

	public boolean imageUpdate( Image image, int infoflags, int x, int y, int width, int height )
	{
		if( infoflags == ImageObserver.ALLBITS ) return false;
		return true;
	}

	public void paint( Graphics gfx )
	{
		gfx.setColor( Color.black );
		gfx.fillRect( 0, 0, getSize().width, getSize().height );

		if( initialized ) gfx.drawImage( bufferImage, bufferX, bufferY, 320 * scale, 200 * scale, this );
	}

	public void repaint( Graphics gfx )
	{
	}

	public void run()
	{
		try
		{
			if( !initialized )
			{
				if( frame == null )
				{
					Graphics gfx = getGraphics();
					if( gfx != null )
					{
						MediaTracker tracker = new MediaTracker( this );
						Image logo = getImage( getCodeBase(), "logo.gif" );
						tracker.addImage( logo, 0 );
						tracker.waitForAll();
						gfx.drawImage( logo, 0, 0, this );
						thread.sleep( 2000 );
					}
				}

				requestFocus();
				addMouseListener( this );
				addMouseMotionListener( this );
				addKeyListener( this );

				bufferImage = createImage( new MemoryImageSource( 320, 200, pixelBuffer, 0, 320 ) );

				if( !initialize() ) return;

				initialized = true;
			}

			while( true )
			{
				if( loadDialog )
				{
					loadDialog = false;

					FileDialog fileDialog = new FileDialog( frame );
					fileDialog.show();
					String fileName = fileDialog.getFile();
					if( fileName != null ) loadPRG( fileDialog.getDirectory() + fileName );
				}

				calculateFrame( 9 );

				Graphics gfx = getGraphics();
				if( gfx != null )
				{
					bufferImage.flush();
					if( scale == 1 ) gfx.drawImage( bufferImage, bufferX, bufferY, this );
					else gfx.drawImage( bufferImage, bufferX, bufferY, 320 * scale, 200 * scale, this );

					if( bufferDragged )
					{
						bufferDragged = false;

						int current = dragCurrentX;
						bufferX += current - dragOriginX;
						dragOriginX = current;

						current = dragCurrentY;
						bufferY += current - dragOriginY;
						dragOriginY = current;

						drawBorders = true;
					}

					if( drawBorders )
					{
						drawBorders = false;

						Dimension dim = getSize();
						int width = dim.width;
						int height = dim.height;

						int xEnd = bufferX + scale * 320;
						int yEnd = bufferY + scale * 200;

						gfx.setColor( Color.black );
						if( bufferX > 0 ) gfx.fillRect( 0, 0, bufferX, height );
						if( bufferY > 0 ) gfx.fillRect( 0, 0, width, bufferY );
						if( xEnd < width ) gfx.fillRect( xEnd, 0, width - xEnd, height );
						if( yEnd < height ) gfx.fillRect( 0, yEnd, width, height - yEnd );
					}
				}

			//	Thread.sleep( 40 );
			}
		}
		catch( InterruptedException e )
		{
			System.out.println( "ERROR. Main thread interrupted." );
			if( frame != null ) frame.dispose();
		}
	}

	public void mousePressed( MouseEvent event )
	{
		requestFocus();

		dragOriginX = event.getX();
		dragOriginY = event.getY();
	}

	public void mouseDragged( MouseEvent event )
	{
		dragCurrentX = event.getX();
		dragCurrentY = event.getY();

		bufferDragged = true;
	}

	public void mouseReleased( MouseEvent event ){}
	public void mouseClicked( MouseEvent event ){}
	public void mouseEntered( MouseEvent event ){}
	public void mouseExited( MouseEvent event ){}
	public void mouseMoved( MouseEvent event ){}

	public void keyPressed( KeyEvent event )
	{
		switch( event.getKeyChar() )
		{
			case '+':
				scale += 1;
				return;

			case '-':
				if( scale == 1 ) break;
				scale -= 1;
				drawBorders = true;
				return;
		}

		byte fifoPos = peekMem[ 0xC6 ];
		if( fifoPos >= 10 ) return;

		int keyCode = event.getKeyCode();
		int c64Key;

		if( ( keyCode >= KeyEvent.VK_A ) && ( keyCode <= KeyEvent.VK_Z ) )
		{
			c64Key = 'A' + keyCode - KeyEvent.VK_A;
		}
		else if( ( keyCode >= '0' ) && ( keyCode <= '9' ) )
		{
			c64Key = keyCode;
		}
		else
		{
			switch( keyCode )
			{
				case KeyEvent.VK_SPACE:
					c64Key = ' ';
					break;

				case KeyEvent.VK_ENTER:
					c64Key = 0xD;
					break;

				case KeyEvent.VK_NUMPAD7:
					c64Key = '"';
					break;

				case KeyEvent.VK_COMMA:
					c64Key = ',';
					break;

				default:
					return;
			}
		}

		peekMem[ 0x277 + fifoPos ] = (byte)c64Key;
		peekMem[ 0xC6 ] = (byte)( fifoPos + 1 );
	}

	public void keyReleased( KeyEvent event )
	{
		switch( event.getKeyCode() )
		{
		}
	}

	public void keyTyped( KeyEvent event ){}

	public void actionPerformed( ActionEvent event )
	{
		loadDialog = true;
	}
















	private boolean overflow_flag = false;
	private boolean break_flag = true;
	private boolean decimal_flag = false;
	private boolean int_flag = false;
	private boolean carry_flag = false;

	private byte neg_zero_flags = 1;	// both false

	private boolean basicPaged = false;
	private boolean kernalPaged = false;
	private boolean charPaged = false;
	private boolean hardwarePaged = false;

	private byte basicMem[] = new byte[ 8192 ];
	private byte kernalMem[] = new byte[ 8192 ];
	private byte peekMem[] = new byte[ 65536 ];
	private byte charMem[] = new byte[ 4096 ];
	private byte hardwareMem[] = new byte[ 4096 ];
	private byte regs[] = hardwareMem;
	private int regsOff = 0;

	private byte vicRegs[] = new byte[ 0x2F ];

	boolean enable1a, enable1b, enable2a, enable2b, vic_den;
	byte vic_ec, vic_b0c;

	int vic_y, vic_vm, vic_cb, vic_bank;
	int latch1a=0, latch2a=0, latch1b=0, latch2b=0;
	byte cpuport, vic_yscrl, vic_xscrl, vic_b1c, vic_b2c, vic_b3c;
	boolean vic_ecm, vic_bmm, vic_rsel, vic_mcm, vic_csel;
	boolean irq = false;
	byte icr1set=0, icr2set=0;
	byte t1a, t2a, t1b, t2b;

	int curr_loc;
	boolean nmi = false;
	int vic_rasirq = 0xFFFF;

	byte stack_ptr = (byte)0xFF; 
	byte a_reg=0,x_reg=0,y_reg=0;

	int skip_cycles = 0;

	private final InputStream openInputStream( String name )
	throws Exception
	{
		InputStream stream;

		if( frame != null ) stream = new FileInputStream( new File( name ) );
		else stream = new URL( getCodeBase(), name ).openStream();

		return new BufferedInputStream( stream );
	}

	private final int readFile( String name, byte dest[], int off, int len )
	throws Exception
	{
		InputStream stream = openInputStream( name );
		int bytes = stream.read( dest, off, len );
		stream.close();

		return bytes;
	}

	private final void loadROM( String name, byte dest[] )
	throws Exception
	{
		if( readFile( "roms/" + name + ".rom", dest, 0, dest.length ) != dest.length )
			throw new Exception();
	}

	private final void loadPRG( String name )
	{
		boolean basicOn = basicPaged;
		boolean kernalOn = kernalPaged;
		boolean hardwareOn = hardwarePaged;
		boolean charOn = charPaged;

		if( basicOn ) swapBasic();
		if( kernalOn ) swapKernal();
		if( hardwareOn ) swapHardware();
		else if( charOn ) swapChar();

		int address;

		try
		{
			InputStream stream = openInputStream( name );
			address = ( 0xFF & stream.read() ) + ( ( 0xFF & stream.read() ) << 8 );
			stream.read( peekMem, address, 0x10000 - address );
			stream.close();
		}
		catch( Exception e )
		{
			address = -1;
		}

		if( basicOn ) swapBasic();
		if( kernalOn ) swapKernal();
		if( hardwareOn ) swapHardware();
		else if( charOn ) swapChar();

		if( address >= 0 )
		{
			peekMem[ 0x2E ] = peekMem[ 0x30 ]= peekMem[ 0x32 ]= (byte)( ( address - 1 ) >> 8 ); 
			peekMem[ 0x2D ] = (byte)( address++ - 1 );
			peekMem[ 0x2F ] = (byte)( address++ - 1 );
			peekMem[ 0x31 ] = (byte)( address++ - 1 );
		}
	}

	private final boolean initialize()
	{
		try
		{
			loadROM( "basic", basicMem );
			loadROM( "kernal", kernalMem );
			loadROM( "char", charMem );
		}
		catch( Exception e )
		{
			System.out.println( "ERROR. Couldn't load rom files." );
			return false;
		}

		curr_loc = ( 0xFF & kernalMem[ 0x1FFC ] ) + ( 0xFF00 & ( kernalMem[ 0x1FFD ] << 8 ) );

		clearMem();

		return true;
	}

	private final void clearMem()
	{
		if( basicPaged ) swapBasic();
		if( kernalPaged ) swapKernal();
		if( charPaged ) swapChar();
		if( hardwarePaged ) swapHardware();

		for( int i=0; i<65535; i++ )
		{
			if( ( i & 0x80 ) == 0 ) peekMem[ i ] = (byte)0x99;
			else peekMem[ i ] = 0x66;
		}

		for( int i=0; i<0x2F; i++ ) vicRegs[ i ] = 0;

		peekMem[ 0 ] = 0x2F;
		peekMem[ 1 ] = 0x37;

		enable1a = enable1b = enable2a = enable2b = vic_den = false;
		vic_ec = vic_b0c = 0;

		for( int i=0; i<0x1000; i++ ) hardwareMem[ i ] = 0;
		hardwareMem[ 0x19 ] = 6;
		for( int i=0x2F; i<0x400; i++ ) hardwareMem[ i ] = -1;
		for( int i=0x041D; i<0x0800; i++ ) hardwareMem[ i ] = -1;
		for( int i=0x0BE8; i<0x0C00; i++ ) hardwareMem[ i ] = -1;
		for( int i=0x0E00; i<0x0FA0; i++ ) hardwareMem[ i ] = -1;

		swapBasic();
		swapKernal();
		swapHardware();
	}

	private final void swapBasic()
	{
		for( int i=0; i<0x2000; i++ )
		{
			byte temp =  basicMem[ i ];
			basicMem[ i ] = peekMem[ 0xA000 + i ];
			peekMem[ 0xA000 + i ]  = temp;
		}

		basicPaged = !basicPaged;
	}

	private final void swapKernal()
	{
		for( int i=0; i<0x2000; i++ )
		{
			byte temp =  kernalMem[ i ];
			kernalMem[ i ] = peekMem[ 0xE000 + i ];
			peekMem[ 0xE000 + i ]  = temp;
		}

		kernalPaged = !kernalPaged;
	}

	private final void swapChar()
	{
		for( int i=0; i<0x1000; i++ )
		{
			byte temp =  charMem[ i ];
			charMem[ i ] = peekMem[ 0xD000 + i ];
			peekMem[ 0xD000 + i ]  = temp;
		}

		charPaged = !charPaged;
	}

	private final void swapHardware()
	{
		for( int i=0; i<0x1000; i++ )
		{
			byte temp =  hardwareMem[ i ];
			hardwareMem[ i ] = peekMem[ 0xD000 + i ];
			peekMem[ 0xD000 + i ]  = temp;
		}

		hardwarePaged = !hardwarePaged;

		if( hardwarePaged )
		{
			regs = peekMem;
			regsOff = 0xD000;
		}
		else
		{
			regs = hardwareMem;
			regsOff = 0;
		}
	}

	private final byte getFlags()
	{
		byte flags = 32;

		if( neg_zero_flags == 0 ) flags += 2;
		else flags += neg_zero_flags & 0x80;

		if( overflow_flag ) flags += 64;
		if( break_flag ) flags += 16;
		if( decimal_flag ) flags += 8;
		if( int_flag ) flags += 4;
		if( carry_flag ) flags += 1;

		return flags;
	}

	private final void setFlags( byte flags )
	{
		if( ( flags & 2 ) != 0 ) neg_zero_flags = 0;
		else neg_zero_flags = (byte)( ( flags & 0x80 ) + 1 );

		overflow_flag = ( flags & 64 ) != 0;
		break_flag = ( flags & 16 ) != 0;
		decimal_flag = ( flags & 8 ) != 0;
		int_flag = ( flags & 4 ) != 0;
		carry_flag = ( flags & 1 ) != 0;
	}

	private final void calculateFrame( int skipFrames )
	{
	/*	byte skip_cycles = this.skip_cycles;
		byte neg_zero_flags = this.neg_zero_flags;	FOR FUTURE USE
		boolean carry_flag = this.carry_flag;
		byte a_reg = this.a_reg;
		byte x_reg = this.x_reg;
		byte y_reg = this.y_reg;
		boolean decimal_flag = this.decimal_flag;
		boolean int_flag = this.int_flag;
		boolean break_flag = this.break_flag;
		boolean overflow_flag = this.overflow_flag;*/

		while( skipFrames-- >= 0 )
		{
			int vic_x = 506;
			int vic_y = -1;

			int pokeDest = -1;
			byte pokeVal = 0;

			regs[ regsOff + 0x11 ] &= 0x7F;

			while( true )
			{
				vic_x += 8;

				if( vic_x >= 506 )
				{
					vic_x = 0;

					if( ++vic_y == 312 )
					{
						break;
					}
					else if( vic_y == 0x100 )
					{
						regs[ regsOff + 0x11 ] |= 0x80;
					}

					regs[ regsOff + 0x12 ] = (byte)vic_y;

					if( vic_y == vic_rasirq )
					{
						if( ( vicRegs[ 0x1A ] & 0x1 ) != 0 )
						{
							irq = true;
							vicRegs[ 0x19 ] |= 0x81;
						}
						else vicRegs[ 0x19 ] |= 1;

						regs[ regsOff + 0x19 ] = (byte)( vicRegs[ 0x19 ] |= 6 );
					}
				}

				if( skip_cycles > 0 )
				{
					skip_cycles--;
				}
				else
				{
					boolean skip = false;

					if( irq )
					{
						irq = false;

						if( !int_flag )
						{
							peekMem[ 0x100 + ( 0xFF & (int)stack_ptr-- ) ] = (byte)( curr_loc >> 8 );
							peekMem[ 0x100 + ( 0xFF & (int)stack_ptr-- ) ] = (byte)curr_loc;
							peekMem[ 0x100 + ( 0xFF & (int)stack_ptr-- ) ] = (byte)( getFlags() & 239 );
							curr_loc = deek( 0xFFFE );
							int_flag = true;
						}
						else skip = true;
					}

					if( nmi && !skip )
					{
						nmi = false;

						peekMem[ 0x100 + ( 0xFF & (int)stack_ptr-- ) ] = (byte)( curr_loc >> 8 );
						peekMem[ 0x100 + ( 0xFF & (int)stack_ptr-- ) ] = (byte)curr_loc;
						peekMem[ 0x100 + ( 0xFF & (int)stack_ptr-- ) ] = getFlags();
						curr_loc = deek( 0xFFFA );
					}

					switch( 0xFF & peekMem[ curr_loc++ ] )
					{
						case 0x00:	// BRK();
							peekMem[ 0x100 + ( 0xFF & (int)stack_ptr-- ) ] = (byte)( ( curr_loc + 1 ) >> 8 );
							peekMem[ 0x100 + ( 0xFF & (int)stack_ptr-- ) ] = (byte)( curr_loc + 1 );
							peekMem[ 0x100 + ( 0xFF & (int)stack_ptr-- ) ] = getFlags();
							int_flag = true;
							curr_loc = deek( 0xFFFE );
							skip_cycles = 5;
							break;

						case 0x01:	// ORA_IndX();
							a_reg |= peekMem[ deek( 0xFF & ( peekMem[ curr_loc++ ] + x_reg ) ) ];
							neg_zero_flags = a_reg;
							skip_cycles = 4;
							break;

						case 0x05:	// ORA_Zero();
							a_reg |= peekMem[ 0xFF & peekMem[ curr_loc++ ] ];
							neg_zero_flags = a_reg;
							skip_cycles = 1;
							break;

						case 0x06:	// ASL_Zero();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							byte val = peekMem[ address ];
							carry_flag = val < 0;
							val <<= 1;
							pokeDest = address;
							pokeVal = val;
							neg_zero_flags = val;
							skip_cycles = 3;
							break;
						}

						case 0x08:	// PHP();
							peekMem[ 0x100 + ( 0xFF & (int)stack_ptr-- ) ] = getFlags();
							skip_cycles = 1;
							break;

						case 0x09:	// ORA_Imm();
							a_reg |= peekMem[ curr_loc++ ];
							neg_zero_flags = a_reg;
							break;

						case 0x0A:	// ASL_Acc();
							carry_flag = a_reg < 0;
							a_reg <<= 1;
							neg_zero_flags = a_reg;
							break;

						case 0x0D:	// ORA_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							a_reg |= peekMem[ address ];
							neg_zero_flags = a_reg;
							skip_cycles = 2;
							break;
						}

						case 0x0E:	// ASL_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							byte val = peekMem[ address ];
							carry_flag = val < 0;
							val <<= 1;
							pokeDest = address;
							pokeVal = val;
							neg_zero_flags = val;
							skip_cycles = 4;
							break;
						}

						case 0x10:	// BPL();
							if( neg_zero_flags >= 0 )
							{
								skip_cycles = 1;
								curr_loc += peekMem[ curr_loc ];
							}
							curr_loc++;
							break;

						case 0x11:	// ORA_Ind_Y();
							a_reg |= peekMem[ deek( 0xFF & peekMem[ curr_loc++ ] ) + ( 0xFF & y_reg ) ];
							neg_zero_flags = a_reg;
							skip_cycles = 3;
							break;

						case 0x15:	// ORA_Zero_X();
							a_reg |= peekMem[ 0xFF & ( peekMem[ curr_loc++ ] + x_reg ) ];
							neg_zero_flags = a_reg;
							skip_cycles = 2;
							break;

						case 0x16:	// ASL_Zero_X();
						{
							int address = 0xFF & ( peekMem[ curr_loc++ ] + x_reg );
							byte val = peekMem[ address ];
							carry_flag = val < 0;
							val <<= 1;
							pokeDest = address;
							pokeVal = val;
							neg_zero_flags = val;
							skip_cycles = 4;
							break;
						}

						case 0x18:	// CLC();
							carry_flag = false;
							break;

						case 0x19:	// ORA_Abs_Y();
						{
							int address = deek( curr_loc ) + ( 0xFF & y_reg );
							curr_loc += 2;
							a_reg |= peekMem[ address ];
							neg_zero_flags = a_reg;

							if( ( ( address - ( 0xFF & (int)y_reg ) ) / 256 ) == ( address / 256 ) )
								skip_cycles = 3;
							else skip_cycles = 4;
							break;
						}

						case 0x1D:	// ORA_Abs_X();
						{
							int address = deek( curr_loc ) + ( 0xFF & x_reg );
							curr_loc += 2;
							a_reg |= peekMem[ address ];
							neg_zero_flags = a_reg;

							if( ( ( address - ( 0xFF & (int)x_reg ) ) / 256 ) == ( address / 256 ) )
								skip_cycles = 3;
							else skip_cycles = 4;
							break;
						}

						case 0x1E:	// ASL_Abs_X();
						{
							int address = deek( curr_loc ) + ( 0xFF & x_reg );
							curr_loc += 2;
							byte val = peekMem[ address ];
							carry_flag = val < 0;
							val <<= 1;
							pokeDest = address;
							pokeVal = val;
							neg_zero_flags = val;
							skip_cycles = 5;
							break;
						}

						case 0x20:	// JSR();
						        curr_loc++;
							peekMem[ 0x100 + ( 0xFF & (int)stack_ptr-- ) ] = (byte)( curr_loc >> 8 );
							peekMem[ 0x100 + ( 0xFF & (int)stack_ptr-- ) ] = (byte)curr_loc;
							curr_loc = deek( curr_loc - 1 );
							break;

						case 0x21:	// AND_IndX();
							a_reg &= peekMem[ deek( 0xFF & ( peekMem[ curr_loc++ ] + x_reg ) ) ];
							neg_zero_flags = a_reg;
							skip_cycles = 4;
							break;

						case 0x24:	// BIT_Zero();
						{
							byte val = peekMem[ 0xFF & peekMem[ curr_loc++ ] ];
							overflow_flag = ( val & 0x40 ) != 0;
							val &= a_reg;
							neg_zero_flags = val;
							skip_cycles = 1;
							break;
						}

						case 0x25:	// AND_Zero();
							a_reg &= peekMem[ 0xFF & peekMem[ curr_loc++ ] ];
							neg_zero_flags = a_reg;
							skip_cycles = 1;
							break;

						case 0x26:	// ROL_Zero();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							byte val = peekMem[ address ];
							boolean new_carry = val < 0;
							val <<= 1;
							if( carry_flag ) val++;
							carry_flag = new_carry;
							neg_zero_flags = val;
							pokeDest = address;
							pokeVal = val;
							skip_cycles = 3;
							break;
						}

						case 0x28:	// PLP();
							setFlags( (byte)( peekMem[ 0x100 + ( 0xFF & (int)(++stack_ptr) ) ] | 0x30 ) );
							skip_cycles = 2;
							break;

						case 0x29:	// AND_Imm();
							a_reg &= peekMem[ curr_loc++ ];
							neg_zero_flags = a_reg;
							break;

						case 0x2A:	// ROL_Acc();
						{
							boolean new_carry = a_reg < 0;
							a_reg <<= 1;
							if( carry_flag ) a_reg++;
							carry_flag = new_carry;
							neg_zero_flags = a_reg;
							break;
						}

						case 0x2C:	// BIT_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							byte val = peekMem[ address ];
							overflow_flag = ( val & 0x40 ) != 0;
							val &= a_reg;
							neg_zero_flags = val;
							skip_cycles = 2;
							break;
						}

						case 0x2D:	// AND_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							a_reg &= peekMem[ address ];
							neg_zero_flags = a_reg;
							skip_cycles = 2;
							break;
						}

						case 0x2E:	// ROL_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							byte val = peekMem[ address ];
							boolean new_carry = val < 0;
							val <<= 1;
							if( carry_flag ) val++;
							carry_flag = new_carry;
							neg_zero_flags = val;
							pokeDest = address;
							pokeVal = val;
							skip_cycles = 4;
							break;
						}

						case 0x30:	// BMI();
							if( neg_zero_flags < 0 )
							{
								curr_loc += peekMem[ curr_loc ];
								skip_cycles = 1;
							}
							curr_loc++;
							break;

						case 0x31:	// AND_Ind_Y();
						{
							int address = deek( 0xFF & peekMem[ curr_loc++ ] ) + ( 0xFF & y_reg );
							a_reg &= peekMem[ address ];
							neg_zero_flags = a_reg;
							skip_cycles = 3;
							break;
						}

						case 0x35:	// AND_Zero_X();
						{
							int address = 0xFF & ( peekMem[ curr_loc++ ] + x_reg );
							a_reg &= peekMem[ address ];
							neg_zero_flags = a_reg;
							skip_cycles = 2;
							break;
						}

						case 0x36:	// ROL_Zero_X();
						{
							int address = 0xFF & ( peekMem[ curr_loc++ ] + x_reg );
							byte val = peekMem[ address ];
							boolean new_carry = val < 0;
							val <<= 1;
							if( carry_flag ) val++;
							carry_flag = new_carry;
							neg_zero_flags = val;
							pokeDest = address;
							pokeVal = val;
							skip_cycles = 3;
							break;
						}

						case 0x38:	// SEC();
							carry_flag = true;
							break;

						case 0x39:	// AND_Abs_Y();
						{
							int address = deek( curr_loc ) + ( 0xFF & y_reg );
							curr_loc += 2;
							a_reg &= peekMem[ address ];
							neg_zero_flags = a_reg;

							if( ( ( address - ( 0xFF & (int)y_reg ) ) / 256 ) == ( address / 256 ) )
								skip_cycles = 3;
							else skip_cycles = 4;
							break;
						}

						case 0x3D:	// AND_Abs_X();
						{
							int address = deek( curr_loc ) + ( 0xFF & x_reg );
							curr_loc += 2;
							a_reg &= peekMem[ address ];
							neg_zero_flags = a_reg;

							if( ( ( address - (int)( 0xFF & x_reg ) ) / 256 ) == ( address / 256 ) )
								skip_cycles = 3;
							else skip_cycles = 4;
							break;
						}

						case 0x3E:	// ROL_Abs_X();
						{
							int address = deek( curr_loc ) + ( 0xFF & x_reg );
							curr_loc += 2;
							byte val = peekMem[ address ];
							boolean new_carry = val < 0;
							val <<= 1;
							if( carry_flag ) val++;
							carry_flag = new_carry;
							neg_zero_flags = val;
							pokeDest = address;
							pokeVal = val;
							skip_cycles = 4;
							break;
						}

						case 0x40:	// RTI();
							setFlags( (byte)( peekMem[ 0x100 + ( 0xFF & (int)(++stack_ptr) ) ] | 0x30 ) );
							curr_loc = 0xFF & peekMem[ 0x100 + ( 0xFF & (int)(++stack_ptr) ) ];
							curr_loc += 0xFF00 & ( peekMem[ 0x100 + ( 0xFF & (int)(++stack_ptr) ) ] << 8 );
							skip_cycles = 4;
							break;

						case 0x41:	// EOR_IndX();
						{
							int address = 0xFF & ( peekMem[ curr_loc++ ] + x_reg );
							address = deek( address );
							a_reg ^= peekMem[ address ];
							neg_zero_flags = a_reg;
							skip_cycles = 4;
							break;
						}

						case 0x45:	// EOR_Zero();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							a_reg ^= peekMem[ address ];
							neg_zero_flags = a_reg;
							skip_cycles = 1;
							break;
						}

						case 0x46:	// LSR_Zero();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							byte val = peekMem[ address ];
							carry_flag = ( val & 1 ) != 0;
							val >>= 1;
							val &= 0x7F;	// really necessary?!
							neg_zero_flags = val;
							pokeDest = address;
							pokeVal = val;
							skip_cycles = 3;
							break;
						}

						case 0x48:	// PHA();
							peekMem[ 0x100 + ( 0xFF & (int)stack_ptr-- ) ] = a_reg;
							skip_cycles = 1;
							break;

						case 0x49:	// EOR_Imm();
							a_reg ^= peekMem[ curr_loc++ ];
							neg_zero_flags = a_reg;
							break;

						case 0x4A:	// LSR_Acc();
							carry_flag = ( a_reg & 1 ) != 0;
							a_reg >>= 1;
							a_reg &= 0x7F;
							neg_zero_flags = a_reg;
							break;

						case 0x4C:	// JMP_Abs();
							curr_loc = deek( curr_loc );
							skip_cycles = 1;
							break;

						case 0x4D:	// EOR_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							a_reg ^= peekMem[ address ];
							neg_zero_flags = a_reg;
							skip_cycles = 2;
							break;
						}

						case 0x4E:	 // LSR_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							byte val = peekMem[ address ];
							carry_flag = ( val & 1 ) != 0;
							val >>= 1;
							val &= 0x7F;
							neg_zero_flags = val;
							pokeDest = address;
							pokeVal = val;
							skip_cycles = 4;
							break;
						}

						case 0x50:	// BVC();
							if( !overflow_flag )
							{
								curr_loc += peekMem[ curr_loc ];
								skip_cycles = 1;
							}
							curr_loc++;
							break;

						case 0x51:	// EOR_Ind_Y();
							a_reg ^= peekMem[ deek( 0xFF & peekMem[ curr_loc++ ] ) + ( 0xFF & y_reg ) ];
							neg_zero_flags = a_reg;
							skip_cycles = 3;
							break;

						case 0x55:	// EOR_Zero_X();
							a_reg ^= peekMem[ 0xFF & ( peekMem[ curr_loc++ ] + x_reg ) ];
							neg_zero_flags = a_reg;
							skip_cycles = 2;
							break;

						case 0x56:	// LSR_Zero_X();
						{
							int address = 0xFF & ( peekMem[ curr_loc++ ] + x_reg );
							byte val = peekMem[ address ];
							carry_flag = ( val & 1 ) != 0;
							val >>= 1;
							val &= 0x7F;
							neg_zero_flags = val;
							pokeDest = address;
							pokeVal = val;
							skip_cycles = 4;
							break;
						}

						case 0x58:	// CLI();
							int_flag = false;
							break;

						case 0x59:	// EOR_Abs_Y();
						{
							int address = deek( curr_loc ) + ( 0xFF & y_reg );
							curr_loc += 2;
							a_reg ^= peekMem[ address ];
							neg_zero_flags = a_reg;

							if( ( ( address - ( 0xFF & (int) y_reg ) ) / 256 ) == ( address / 256 ) )
								skip_cycles = 3;
							else skip_cycles = 4;
							break;
						}

						case 0x5D:	// EOR_Abs_X();
						{
							int address = deek( curr_loc ) + ( 0xFF & x_reg );
							curr_loc += 2;
							a_reg ^= peekMem[ address ];
							neg_zero_flags = a_reg;

							if( ( ( address - ( 0xFF & (int)x_reg ) ) / 256 ) == ( address / 256 ) )
								skip_cycles = 3;
							else skip_cycles = 4;
							break;
						}

						case 0x5E:	// LSR_Abs_X();
						{
							int address = deek( curr_loc ) + ( 0xFF & x_reg );
							curr_loc += 2;
							byte val = peekMem[ address ];
							carry_flag = ( val & 1 ) != 0;
							val >>= 1;
							val &= 0x7F;
							neg_zero_flags = val;
							pokeDest = address;
							pokeVal = val;
							skip_cycles = 4;
							break;
						}

						case 0x60:	// RTS();
							curr_loc = 0xFF & peekMem[ 0x100 + ( 0xFF & (int)(++stack_ptr) ) ];
							curr_loc += 0xFF00 & ( peekMem[ 0x100 + ( 0xFF & (int)(++stack_ptr) ) ] << 8 );
							curr_loc++;
							skip_cycles = 4;
							break;

						case 0x61:	// ADC_IndX();
						{
							int address = 0xFF & ( peekMem[ curr_loc++ ] + x_reg );
					        	ADC( peekMem[ deek( address ) ] );
							skip_cycles = 4;
							break;
						}

						case 0x65:	// ADC_Zero();
							ADC( peekMem[ 0xFF & peekMem[ curr_loc++ ] ] );
							skip_cycles = 1;
							break;

						case 0x66:	// ROR_Zero();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							byte val = peekMem[ address ];
							boolean new_carry = ( val & 1 ) != 0;
							val >>= 1;
							if( carry_flag ) val |= 0x80;
							else val &= 0x7F;	// really necessary?!
							carry_flag = new_carry;
							neg_zero_flags = val;
							pokeDest = address;
							pokeVal = val;
							skip_cycles = 3;
							break;
						}

						case 0x68:	// PLA();
							a_reg = peekMem[ 0x100 + ( 0xFF & (int)(++stack_ptr) ) ];
							neg_zero_flags = a_reg;
							skip_cycles = 2;
							break;

						case 0x69:	// ADC_Imm();
							ADC( peekMem[ curr_loc++ ] );
							break;

						case 0x6A:	// ROR_Acc();
						{
							boolean new_carry = ( a_reg & 1 ) != 0;
							a_reg >>= 1;
							if( carry_flag ) a_reg |= 0x80;
							else a_reg &= 0x7F;
							carry_flag = new_carry;
							neg_zero_flags = a_reg;
							break;
						}

						case 0x6C:	// JMP_Ind();
						{
							int k = deek( curr_loc );
							curr_loc = 0xFF & peekMem[ k ];
							k++;
							if( ( k & 0xFF ) == 0 ) k -= 0x100;
							curr_loc += peekMem[ k ] << 8;
							curr_loc &= 0xFFFF;
							skip_cycles = 3;
							break;
						}

						case 0x6D:	// ADC_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							ADC( peekMem[ address ] );
							skip_cycles = 2;
							break;
						}

						case 0x6E:	// ROR_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							byte val = peekMem[ address ];
							boolean new_carry = ( val & 1 ) != 0;
							val >>= 1;
							if( carry_flag ) val |= 0x80;
							else val &= 0x7F;
							carry_flag = new_carry;
							neg_zero_flags = val;
							pokeDest = address;
							pokeVal = val;
							skip_cycles = 4;
							break;
						}

						case 0x70:	// BVS();
							if( overflow_flag )
							{
								curr_loc += peekMem[ curr_loc ];
								skip_cycles = 1;
							}
							curr_loc++;
							break;

						case 0x71:	// ADC_Ind_Y();
							ADC( peekMem[ deek( 0xFF & peekMem[ curr_loc++ ] ) + ( 0xFF & y_reg ) ] );
							skip_cycles = 3;
							break;

						case 0x75:	// ADC_Zero_X();
							ADC( peekMem[ 0xFF & ( peekMem[ curr_loc++ ] + x_reg ) ] );
							skip_cycles = 2;
							break;

						case 0x76:	// ROR_Zero_X();
						{
							int address = 0xFF & ( peekMem[ curr_loc++ ] + x_reg );
							byte val = peekMem[ address ];
							boolean new_carry = ( val & 1 ) != 0;
							val >>= 1;
							if( carry_flag ) val |= 0x80;
							else val &= 0x7F;
							carry_flag = new_carry;
							neg_zero_flags = val;
							pokeDest = address;
							pokeVal = val;
							skip_cycles = 3;
							break;
						}

						case 0x78:	// SEI();
							int_flag = true;
							break;

						case 0x79:	// ADC_Abs_Y();
						{
							int address = deek( curr_loc ) + ( 0xFF & y_reg );
							curr_loc += 2;
							ADC( peekMem[ address ] );

							if( ( ( address - ( 0xFF & (int)y_reg ) ) / 256 ) == ( address / 256 ) )
								skip_cycles = 3;
							else skip_cycles = 4;
							break;
						}

						case 0x7D:	// ADC_Abs_X();
						{
							int address = deek( curr_loc ) + ( 0xFF & x_reg );
							curr_loc += 2;
							ADC( peekMem[ address ] );

							if( ( ( address - ( 0xFF & (int)x_reg ) ) / 256 ) == ( address / 256 ) )
								skip_cycles = 3;
							else skip_cycles = 4;
							break;
						}

						case 0x7E:	// ROR_Abs_X();
						{
							int address = deek( curr_loc ) + ( 0xFF & x_reg );
							curr_loc += 2;
							byte val = peekMem[ address ];
							boolean new_carry = ( val & 1 ) != 0;
							val >>= 1;
							if( carry_flag ) val |= 0x80;
							else val &= 0x7F;
							carry_flag = new_carry;
							neg_zero_flags = val;
							pokeDest = address;
							pokeVal = val;
							skip_cycles = 4;
							break;
						}

						case 0x81:	// STA_IndX();
							pokeDest = deek( 0xFF & ( peekMem[ curr_loc++ ] + x_reg ) );
							pokeVal = a_reg;
							skip_cycles = 4;
							break;

						case 0x84:	// STY_Zero();
							pokeDest = 0xFF & peekMem[ curr_loc++ ];
							pokeVal = y_reg;
							skip_cycles = 1;
							break;

						case 0x85:	// STA_Zero();
							pokeDest = 0xFF & peekMem[ curr_loc++ ];
							pokeVal = a_reg;
							skip_cycles = 1;
							break;

						case 0x86:	// STX_Zero();
							pokeDest = 0xFF & peekMem[ curr_loc++ ];
							pokeVal = x_reg;
							skip_cycles = 1;
							break;

						case 0x88:	// DEY();
							neg_zero_flags = --y_reg;
							break;

						case 0x8A:	// TXA();
							neg_zero_flags = a_reg = x_reg;
							break;

						case 0x8C:	// STY_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							pokeDest = address;
							pokeVal = y_reg;
							skip_cycles = 2;
							break;
						}

						case 0x8D:	// STA_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							pokeDest = address;
							pokeVal = a_reg;
							skip_cycles = 2;
							break;
						}

						case 0x8E:	// STX_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							pokeDest = address;
							pokeVal = x_reg;
							skip_cycles = 2;
							break;
						}

						case 0x90:	// BCC();
							if( !carry_flag )
							{
								curr_loc += peekMem[ curr_loc ];
								skip_cycles = 1;
							}
							curr_loc++;
							break;

						case 0x91:	// STA_Ind_Y();
							pokeDest = deek( 0xFF & peekMem[ curr_loc++ ] ) + ( 0xFF & y_reg );
							pokeVal = a_reg;
							skip_cycles = 4;
							break;

						case 0x94:	// STY_Zero_X();
							pokeDest = 0xFF & ( peekMem[ curr_loc++ ] + x_reg );
							pokeVal = y_reg;
							skip_cycles = 2;
							break;

						case 0x95:	// STA_Zero_X();
							pokeDest = 0xFF & ( peekMem[ curr_loc++ ] + x_reg );
							pokeVal = a_reg;
							skip_cycles = 2;
							break;

						case 0x96:	// STX_Zero_Y();
							pokeDest = 0xFF & ( peekMem[ curr_loc++ ] + y_reg );
							pokeVal = x_reg;
							skip_cycles = 2;
							break;

						case 0x98:	// TYA();
							neg_zero_flags = a_reg = y_reg;
							break;

						case 0x99:	// STA_Abs_Y();
							pokeDest = deek( curr_loc ) + ( 0xFF & y_reg );
							pokeVal = a_reg;
							curr_loc += 2;
							skip_cycles = 3;
							break;

						case 0x9A:	// TXS();
							stack_ptr = x_reg;
							break;

						case 0x9D:	// STA_Abs_X();
							pokeDest = deek( curr_loc ) + ( 0xFF & x_reg );
							pokeVal = a_reg;
							curr_loc += 2;
							skip_cycles = 3;
							break;

						case 0xA0:	// LDY_Imm();
							neg_zero_flags = y_reg = peekMem[ curr_loc++ ];
							break;

						case 0xA1:	// LDA_IndX();
							neg_zero_flags = a_reg = peekMem[ deek( 0xFF & ( peekMem[ curr_loc++ ] + x_reg ) ) ];
							skip_cycles = 4;
							break;

						case 0xA2:	// LDX_Imm();
							neg_zero_flags = x_reg = peekMem[ curr_loc++ ];
							break;

						case 0xA4:	// LDY_Zero();
							neg_zero_flags = y_reg = peekMem[ 0xFF & peekMem[ curr_loc++ ] ];
							skip_cycles = 1;
							break;

						case 0xA5:	// LDA_Zero();
							neg_zero_flags = a_reg = peekMem[ 0xFF & peekMem[ curr_loc++ ] ];
							skip_cycles = 1;
							break;

						case 0xA6:	// LDX_Zero();
							neg_zero_flags = x_reg = peekMem[ 0xFF & peekMem[ curr_loc++ ] ];
							skip_cycles = 1;
							break;

						case 0xA8:	// TAY();
							neg_zero_flags = y_reg = a_reg;
							break;

						case 0xA9:	// LDA_Imm();
							neg_zero_flags = a_reg = peekMem[ curr_loc++ ];
							break;

						case 0xAA:	// TAX();
							neg_zero_flags = x_reg = a_reg;
							break;

						case 0xAC:	// LDY_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							neg_zero_flags = y_reg = peekMem[ address ];
							skip_cycles = 2;
							break;
						}

						case 0xAD:	// LDA_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							neg_zero_flags = a_reg = peekMem[ address ];
							skip_cycles = 2;
							break;
						}

						case 0xAE:	// LDX_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							neg_zero_flags = x_reg = peekMem[ address ];
							skip_cycles = 2;
							break;
						}

						case 0xB0:	// BCS();
							if( carry_flag )
							{
								curr_loc += peekMem[ curr_loc ];
								skip_cycles = 1;
							}
							curr_loc++;
							break;

						case 0xB1:	// LDA_Ind_Y();
						{
							int address = deek( 0xFF & peekMem[ curr_loc++ ] ) + ( 0xFF & y_reg );
							neg_zero_flags = a_reg = peekMem[ address ];

							if( ( ( address - ( 0xFF & (int)y_reg ) ) / 256 ) != ( address / 256 ) )
								skip_cycles = 4;
							else skip_cycles = 3;
							break;
						}

						case 0xB4:	// LDY_Zero_X();
							neg_zero_flags = y_reg = peekMem[ 0xFF & ( peekMem[ curr_loc++ ] + x_reg ) ];
							skip_cycles = 2;
							break;

						case 0xB5:	// LDA_Zero_X();
							neg_zero_flags = a_reg = peekMem[ 0xFF & ( peekMem[ curr_loc++ ] + x_reg ) ];
							skip_cycles = 2;
							break;

						case 0xB6:	// LDX_Zero_Y();
							neg_zero_flags = x_reg = peekMem[ 0xFF & ( peekMem[ curr_loc++ ] + y_reg ) ];
							skip_cycles = 2;
							break;

						case 0xB8:	// CLV();
							overflow_flag = false;
							break;

						case 0xB9:	// LDA_Abs_Y();
						{
							int address = deek( curr_loc ) + ( 0xFF & y_reg );
							curr_loc += 2;
							neg_zero_flags = a_reg = peekMem[ address ];

							if( ( ( address - ( 0xFF & (int)y_reg ) ) / 256 ) != ( address / 256 ) )
								skip_cycles = 4;
							else skip_cycles = 3;
							break;
						}

						case 0xBA:	// TSX();
							neg_zero_flags = x_reg = stack_ptr;
							break;

						case 0xBC:	// LDY_Abs_X();
						{
							int address = deek( curr_loc ) + ( 0xFF & x_reg );
							curr_loc += 2;
							neg_zero_flags = y_reg = peekMem[ address ];

							if( ( ( address - ( 0xFF & (int)x_reg ) ) / 256 ) != ( address / 256 ) )
								skip_cycles = 4;
							else skip_cycles = 3;
							break;
						}

						case 0xBD:	// LDA_Abs_X();
						{
							int address = deek( curr_loc ) + ( 0xFF & x_reg );
							curr_loc += 2;
							neg_zero_flags = a_reg = peekMem[ address ];

							if( ( ( address - ( 0xFF & (int)x_reg ) ) / 256 ) != ( address / 256 ) )
								skip_cycles = 4;
							else skip_cycles = 3;
							break;
						}

						case 0xBE:	// LDX_Abs_Y();
						{
							int address = deek( curr_loc ) + ( 0xFF & y_reg );
							curr_loc += 2;
							neg_zero_flags = x_reg = peekMem[ address ];

							if( ( ( address - ( 0xFF & (int)y_reg ) ) / 256 ) != ( address / 256 ) )
								skip_cycles = 4;
							else skip_cycles = 3;
							break;
						}

						case 0xC0:	// CPY_Imm();
						{
							byte val = peekMem[ curr_loc++ ];
							carry_flag = ( 0xFF & val ) <= ( 0xFF & y_reg );
							neg_zero_flags = (byte)( y_reg - val );
							break;
						}

						case 0xC1:	// CMP_IndX();
						{
							int address = 0xFF & ( peekMem[ curr_loc++ ] + x_reg );
							address = deek( address );
							byte val = peekMem[ address ];
							carry_flag = ( 0xFF & val ) <= ( 0xFF & a_reg );
							neg_zero_flags = (byte)( a_reg - val );
							skip_cycles = 4;
							break;
						}

						case 0xC4:	// CPY_Zero();
						{
							byte val = peekMem[ 0xFF & peekMem[ curr_loc++ ] ];
							carry_flag = ( 0xFF & val ) <= ( 0xFF & y_reg );
							neg_zero_flags = (byte)( y_reg - val );
							skip_cycles = 2;
							break;
						}

						case 0xC5:	// CMP_Zero();
						{
							byte val = peekMem[ 0xFF & peekMem[ curr_loc++ ] ];
							carry_flag = ( 0xFF & val ) <= ( 0xFF & a_reg );
							neg_zero_flags = (byte)( a_reg - val );
							skip_cycles = 1;
							break;
						}

						case 0xC6:	// DEC_Zero();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							byte val = peekMem[ address ];
							pokeDest = address;
							pokeVal = neg_zero_flags = --val;
							skip_cycles = 3;
							break;
						}

						case 0xC8:	// INY();
							neg_zero_flags = ++y_reg;
							break;

						case 0xC9:	// CMP_Imm();
						{
							byte val = peekMem[ curr_loc++ ];
							carry_flag = ( 0xFF & val ) <= ( 0xFF & a_reg );
							neg_zero_flags = (byte)( a_reg - val );
							break;
						}

						case 0xCA:	// DEX();
							neg_zero_flags = --x_reg;
							break;

						case 0xCC:	// CPY_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							byte val = peekMem[ address ];
							carry_flag = ( 0xFF & val ) <= ( 0xFF & y_reg );
							neg_zero_flags = (byte)( y_reg - val );
							skip_cycles = 2;
							break;
						}

						case 0xCD:	// CMP_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							byte val = peekMem[ address ];
							carry_flag = ( 0xFF & val ) <= ( 0xFF & a_reg );
							neg_zero_flags = (byte)( a_reg - val );
							skip_cycles = 2;
							break;
						}

						case 0xCE:	// DEC_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							byte val = peekMem[ address ];
							pokeDest = address;
							pokeVal = neg_zero_flags = --val;
							skip_cycles = 4;
							break;
						}

						case 0xD0:	// BNE();
							if( neg_zero_flags != 0 )
							{
								curr_loc += peekMem[ curr_loc ];
								skip_cycles = 1;
							}
							curr_loc++;
							break;

						case 0xD1:	// CMP_Ind_Y();
						{
							int address = deek( 0xFF & peekMem[ curr_loc++ ] ) + ( 0xFF & y_reg );
							byte val = peekMem[ address ];
							carry_flag = ( 0xFF & val ) <= ( 0xFF & a_reg );
							neg_zero_flags = (byte)( a_reg - val );

							if( ( ( address - ( 0xFF & (int)y_reg ) ) / 256 ) != ( address / 256 ) )
								skip_cycles = 4;
							else skip_cycles = 3;
							break;
						}

						case 0xD5:	// CMP_Zero_X();
						{
							int address = 0xFF & ( peekMem[ curr_loc++ ] + x_reg );
							byte val = peekMem[ address ];
							carry_flag = ( 0xFF & val ) <= ( 0xFF & a_reg );
							neg_zero_flags = (byte)( a_reg - val );
							skip_cycles = 2;
							break;
						}

						case 0xD6:	// DEC_Zero_X();
						{
							int address = 0xFF & ( peekMem[ curr_loc++ ] + x_reg );
							byte val = peekMem[ address ];
							pokeDest = address;
							pokeVal = neg_zero_flags = --val;
							skip_cycles = 4;
							break;
						}

						case 0xD8:	// CLD();
							decimal_flag = false;
							break;

						case 0xD9:	// CMP_Abs_Y();
						{
							int address = deek( curr_loc ) + ( 0xFF & y_reg );
							curr_loc += 2;
							byte val = peekMem[ address ];
							carry_flag = ( 0xFF & val ) <= ( 0xFF & a_reg );
							neg_zero_flags = (byte)( a_reg - val );

							if( ( ( address - ( 0xFF & (int)y_reg ) ) / 256 ) != ( address / 256 ) )
								skip_cycles = 3;
							else skip_cycles = 2;
							break;
						}

						case 0xDD:	// CMP_Abs_X();
						{
							int address = deek( curr_loc ) + ( 0xFF & x_reg );
							curr_loc += 2;
							byte val = peekMem[ address ];
							carry_flag = ( 0xFF & val ) <= ( 0xFF & a_reg );
							neg_zero_flags = (byte)( a_reg - val );

							if( ( ( address - ( 0xFF & (int)x_reg ) ) / 256 ) != ( address / 256 ) )
								skip_cycles = 3;
							else skip_cycles = 2;
							break;
						}

						case 0xDE:	// DEC_Abs_X();
						{
							int address = deek( curr_loc ) + ( 0xFF & x_reg );
							curr_loc += 2;
							byte val = peekMem[ address ];
							pokeDest = address;
							pokeVal = neg_zero_flags = --val;
							skip_cycles = 5;
							break;
						}

						case 0xE0:	// CPX_Imm();
						{
							byte val = peekMem[ curr_loc++ ];
							carry_flag = ( 0xFF & val ) <= ( 0xFF & x_reg );
							neg_zero_flags = (byte)( x_reg - val );
							break;
						}

						case 0xE1:	// SBC_IndX();
						{
							int address = 0xFF & ( peekMem[ curr_loc++ ] + x_reg );
							SBC( peekMem[ deek( address ) ] );
							skip_cycles = 4;
							break;
						}

						case 0xE4:	// CPX_Zero();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							byte val = peekMem[ address ];
							carry_flag = ( 0xFF & val ) <= ( 0xFF & x_reg );
							neg_zero_flags = (byte)( x_reg - val );
							skip_cycles = 1;
							break;
						}

						case 0xE5:	// SBC_Zero();
							SBC( peekMem[ 0xFF & peekMem[ curr_loc++ ] ] );
							skip_cycles = 1;
							break;

						case 0xE6:	// INC_Zero();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							byte val = peekMem[ address ];
							pokeDest = address;
							pokeVal = neg_zero_flags = ++val;
							skip_cycles = 3;
							break;
						}

						case 0xE8:	// INX();
							neg_zero_flags = ++x_reg;
							break;

						case 0xE9:	// SBC_Imm();
							SBC( peekMem[ curr_loc++ ] );
							break;

						case 0xEC:	// CPX_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							byte val = peekMem[ address ];
							carry_flag = ( 0xFF & val ) <= ( 0xFF & x_reg );
							neg_zero_flags = (byte)( x_reg - val );
							skip_cycles = 2;
							break;
						}

						case 0xED:	// SBC_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							SBC( peekMem[ address ] );
							skip_cycles = 2;
							break;
						}

						case 0xEE:	// INC_Abs();
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							address += ( 0xFF & peekMem[ curr_loc++ ] ) << 8;
							byte val = peekMem[ address ];
							pokeDest = address;
							pokeVal = neg_zero_flags = ++val;
							skip_cycles = 4;
							break;
						}

						case 0xF0:	// BEQ();
							if( neg_zero_flags == 0 )
							{
								curr_loc += peekMem[ curr_loc ];
								skip_cycles = 1;
							}
							curr_loc++;
							break;

						case 0xF1:	// SBC_Ind_Y();
							SBC( peekMem[ deek( 0xFF & peekMem[ curr_loc++ ] ) + ( 0xFF & y_reg ) ] );
							skip_cycles = 3;
							break;

						case 0xF5:	// SBC_Zero_X();
							SBC( peekMem[ 0xFF & ( peekMem[ curr_loc++ ] + x_reg ) ] );
							skip_cycles = 2;
							break;

						case 0xF6:	// INC_Zero_X();
						{
							int address = 0xFF & ( peekMem[ curr_loc++ ] + x_reg );
							byte val = peekMem[ address ];
							pokeDest = address;
							pokeVal = neg_zero_flags = ++val;
							skip_cycles = 4;
							break;
						}

						case 0xF8:	// SED();
							decimal_flag = true;
							break;

						case 0xF9:	// SBC_Abs_Y();
						{
							int address = deek( curr_loc ) + ( 0xFF & y_reg );
							curr_loc += 2;
							SBC( peekMem[ address ] );

							if( ( ( address - ( 0xFF & (int)y_reg ) ) / 256 ) == ( address / 256 ) )
								skip_cycles = 3;
							else skip_cycles = 4;
							break;
						}

						case 0xFD:	// SBC_Abs_X();
						{
							int address = deek( curr_loc ) + ( 0xFF & x_reg );
							curr_loc += 2;
							SBC( peekMem[ address ] );

							if( ( ( address - ( 0xFF & (int)x_reg ) ) / 256 ) == ( address / 256 ) )
								skip_cycles = 3;
							else skip_cycles = 4;
							break;
						}

						case 0xFE:	// INC_Abs_X();
						{
							int address = deek( curr_loc ) + ( 0xFF & x_reg );
							curr_loc += 2;
							byte val = peekMem[ address ];
							pokeDest = address;
							pokeVal = neg_zero_flags = ++val;
							skip_cycles = 5;
							break;
						}

						case 0x82:	// SKB
						case 0x80:
						case 0xc2:
						case 0xe2:
						case 0x04:
						case 0x14:
						case 0x34:
						case 0x44:
						case 0x54:
						case 0x64:
						case 0x74:
						case 0x89:	// op tests call it NOP #imm ??
						case 0xD4:
						case 0xf4:
							curr_loc++;
							break;

						case 0x0B:	// ASO_Imm
						{
							byte val = peekMem[ curr_loc++ ];
							if( val < 0 ) carry_flag = true;
							val <<= 1;
							a_reg |= val;
							neg_zero_flags = a_reg;
							skip_cycles = 3;
							break;
						}

						case 0x1F:
						{
							int address = deek( curr_loc ) + ( 0xFF & x_reg );
							curr_loc += 2;
							byte val = peekMem[ address ];
							carry_flag = val < 0;
							val <<= 1;
							pokeDest = address;
							pokeVal = val;
							a_reg |= val;
							neg_zero_flags = a_reg;
							skip_cycles = 7;
							break;
						}

						case 0x67:
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							byte val = peekMem[ address ];
							boolean new_carry = ( val & 1 ) != 0;
							val >>= 1;
							if( carry_flag ) val |= 0x80;
							else val &= 0x7F;
							carry_flag = new_carry;
							pokeDest = address;
							pokeVal = neg_zero_flags = val;
							ADC( val );
							skip_cycles = 4;
							break;
						}

						case 0x87:
							pokeDest = ( 0xFF & peekMem[ curr_loc++ ] );
							pokeVal = (byte)( a_reg & x_reg );
							skip_cycles = 4;
							break;

						case 0xBF:
							neg_zero_flags = a_reg = x_reg = peekMem[ deek( curr_loc ) + ( 0xFF & y_reg ) ];
							curr_loc += 2;
							break;

						case 0xC3:
						{
							int address = 0xFF & (int)( peekMem[ curr_loc++ ] + x_reg );
							address = deek( address );
							byte val = peekMem[ address ];
							pokeDest = address;
							pokeVal = --val;
							carry_flag = ( 0xFF & val ) <= ( 0xFF & a_reg );
							neg_zero_flags = (byte)( a_reg - val );
							skip_cycles = 7;
							break;
						}

						case 0xC7:
						{
							int address = 0xFF & peekMem[ curr_loc++ ];
							byte val = peekMem[ address ];
							pokeDest = address;
							pokeVal = --val;
							carry_flag = ( 0xFF & val ) <= ( 0xFF & a_reg );
							neg_zero_flags = (byte)( a_reg - val );
							skip_cycles = 5;
							break;
						}

						case 0xFF:
						{
							int address = deek( curr_loc ) + ( 0xFF & x_reg );
							curr_loc += 2;
							byte val = (byte)( peekMem[ address ] + 1 );
							pokeDest = address;
							pokeVal = val;
							SBC( val );
							skip_cycles = 7;
							break;
						}

						case 0x0C:	// SKW
						case 0x1C:
						case 0x3C:
						case 0x5C:
						case 0x7C:
						case 0xDC:
						case 0xFC:
							curr_loc += 2;
							break;
					}

					if( pokeDest >= 0 )
					{
						if( pokeDest < 0xA000 )
						{
							switch( pokeDest )
							{
								case 1:
									cpuport = pokeVal;
									pokeVal = peekMem[ 0 ];
									// no break on purpose 

								case 0:
									peekMem[ 0 ] = pokeVal;
									peekMem[ 1 ] &= ~( pokeVal | 0x20 );
									peekMem[ 1 ] |= ( cpuport & pokeVal ) | ( 0x17 & ~pokeVal );

									if( ( ( peekMem[ 1 ] & 3 ) != 0 ) ^ basicPaged ) swapBasic();

									if( ( ( peekMem[ 1 ] & 2 ) != 0 ) ^ kernalPaged ) swapKernal();

									if( ( peekMem[ 1 ] & 3 ) == 0 )
									{
										if( hardwarePaged ) swapHardware();
										else if( charPaged ) swapChar();
									}
									else if( ( peekMem[ 1 ] & 4 ) == 0 )
									{
										if( !charPaged )
										{
											if( hardwarePaged ) swapHardware();
											swapChar();
										}
									}
									else
									{
										if( !hardwarePaged )
										{
											if( charPaged ) swapChar();
											swapHardware();
										}
									}
									break;

								default:
									peekMem[ pokeDest ] = pokeVal;
							}
						}
						else if( pokeDest < 0xC000 )
						{
							if( basicPaged ) basicMem[ pokeDest & 0x1FFF ] = pokeVal;
							else peekMem[ pokeDest ] = pokeVal;
						}
						else if( pokeDest < 0xD000 )
						{
							peekMem[ pokeDest ] = pokeVal;
						}
						else if( pokeDest >= 0xE000 )
						{
							if( kernalPaged ) kernalMem[ pokeDest & 0x1FFF ] = pokeVal;
							else peekMem[ pokeDest ] = pokeVal;
						}
						else
						{
							if( ( peekMem[ 1 ] & 7 ) == 0 ) peekMem[ pokeDest ] = pokeVal;
							else
							{
								if( pokeDest < 0xD400 )	// VIC
								{
									pokeDest &= 0x3F;

									switch( pokeDest )
									{
										case 0x11:
											if( ( pokeVal & 0x40 ) != 0 ) vic_ecm = true;
											else vic_ecm = false;
											if( ( pokeVal & 0x20 ) != 0 ) vic_bmm = true;
											else vic_bmm = false;
											if( ( pokeVal & 0x10 ) != 0 ) vic_den = true;
											else vic_den = false;
											if( ( pokeVal & 8 ) != 0 ) vic_rsel = true;
											else vic_rsel = false;
											vic_yscrl = (byte)( pokeVal & 7 );
											vic_rasirq = 0xFF & (int)vicRegs[ 0x12 ];
											if( ( pokeVal & 0x80 ) != 0 ) vic_rasirq |= 0x100;
											break;

										case 0x12:
											vic_rasirq = 0xFF & (int)pokeVal;
											if( ( vicRegs[ 0x11 ] & 0x80 ) != 0 ) vic_rasirq |= 0x100;
											break;

										case 0x16:
											pokeVal |= 0xA0;
											if( ( pokeVal & 0x10 ) != 0 ) vic_mcm = true;
											else vic_mcm = false;
											if( ( pokeVal & 8 ) != 0 ) vic_csel = true;
											else vic_csel = false;
											vic_xscrl = (byte)( pokeVal & 7 );
											break;

										case 0x18:
											pokeVal |= 1;
											vic_vm = ( (int)pokeVal & 0xF0 ) << 6; 
											vic_cb = ( (int)pokeVal & 0xE ) << 10;
											break;

										case 0x19:
											pokeVal = (byte)( ~( pokeVal & 0xF ) & vicRegs[ 0x19 ] );
											if( ( ( pokeVal & vicRegs[ 0x1A ] & 0xF ) == 0 ) && ( ( pokeVal & 0x80 ) != 0 ) )
											{
												irq = false;
												pokeVal &= 0x7F;
											}
											pokeVal |= 0x70;
											break;

										case 0x1A:
											pokeVal |= 0xF0;
											break;

										case 0x20:
											vic_ec = (byte)( pokeVal & 0xF );
											pokeVal |= 0xF0;
											break;

										case 0x21:
											vic_b0c = (byte)( pokeVal & 0xF );
											pokeVal |= 0xF0;
											break;

										case 0x22:
											vic_b1c = (byte)( pokeVal & 0xF );
											pokeVal |= 0xF0;
											break;

										case 0x23:
											vic_b2c = (byte)( pokeVal & 0xF );
											pokeVal |= 0xF0;
											break;

										case 0x24:
											vic_b3c = (byte)( pokeVal & 0xF );
											pokeVal |= 0xF0;
											break;
									} 

									if( pokeDest < 0x2F )
									{
										vicRegs[ pokeDest ] = pokeVal;

										if( pokeDest != 0x12 )
										{
											if( pokeDest == 0x11 )
											{
												if( ( vic_y & 0x100 ) != 0 ) pokeVal |= 0x80;
												else pokeVal &= 0x7F;
											}
											else if( pokeDest == 0x19 ) pokeVal |= 6;

											regs[ regsOff + pokeDest ] = pokeVal;
										}
									}
								}
								else if( pokeDest < 0xD800 )	// SID
								{
									pokeDest &= 0x1F;

									if( pokeDest < 0x1D ) regs[ regsOff + 0x400 + pokeDest ] = pokeVal;
								}
								else if( pokeDest < 0xDBE8 )	// Color RAM
								{
									regs[ regsOff + ( pokeDest & 0xBFF ) ] = (byte)( pokeVal & 0xF );
								}
								else if( pokeDest < 0xDC00 );	// Nothing
								else if( pokeDest < 0xDD00 )	// CIA 1
								{
									pokeDest &= 0xF;
									regs[ regsOff + 0xC00 + pokeDest ] = pokeVal;

									switch( pokeDest )
									{ 
										case 4:
											latch1a &= 0xFF00;
											latch1a |= 0xFF & pokeVal;
											break;

										case 5:
											latch1a &= 0xFF;
											latch1a |= ( 0xFF & pokeVal ) << 8;
											break;

										case 6:
											latch1b &= 0xFF00;
											latch1b |= 0xFF & pokeVal;
											break;

										case 7:
											latch1b &= 0xFF;
											latch1b |= ( 0xFF & pokeVal ) << 8;

										case 13:
											if( ( pokeVal & 0x01 ) != 0 )
											{
												if( ( pokeVal & 0x80 ) != 0 ) icr1set |= 1;
												else icr1set &= 254;
											}
											if( ( pokeVal & 0x02 ) != 0 )
											{
												if( ( pokeVal & 0x80 ) != 0 ) icr1set |= 2;
												else icr1set &= 253;
											}
											if( ( pokeVal & 0x04 ) != 0 )
											{
												if( ( pokeVal & 0x80 ) != 0 ) icr1set |= 4;
												else icr1set &= 251;
											}
											if( ( pokeVal & 0x08 ) != 0 )
											{
												if( ( pokeVal & 0x80 ) != 0 ) icr1set |= 8;
												else icr1set &= 247;
											}
											if( ( pokeVal & 0x10 ) != 0 )
											{
												if( ( pokeVal & 0x80 ) != 0 ) icr1set |= 16;
												else icr1set &= 239;
											}
											break;

										case 14:
											if( ( pokeVal & 0x10 ) != 0 )
											{
												t1a = regs[ regsOff + 0xC04 ] = (byte)latch1a;
												if( ( pokeVal & 0x01 ) != 0 ) enable1a = true;
												else enable1a = false;
											}
											break;

										case 15:
											if( ( pokeVal & 0x10 ) != 0 )
											{
												t1b = regs[ regsOff + 0xC06 ] = (byte)latch1b;
												if( ( pokeVal & 0x1 ) != 0 ) enable1b = true;
												else enable1b = false;
											}
											break;
									}
								}
								else if( pokeDest < 0xDE00 )	// CIA 2
								{
									pokeDest &= 0xF;
									if( pokeDest != 0 ) regs[ regsOff + 0xD00 + pokeDest ] = pokeVal;

									switch( pokeDest )
									{
										case 0:
											vic_bank = ( ~pokeVal & 3 ) << 14 ;
											break;

										case 4:
											latch2a &= 0xFF00;
											latch2a |= 0xFF & pokeVal;
											break;

										case 5:
											latch2a &= 0xFF;
											latch2a |= ( 0xFF & pokeVal ) << 8;
											break;

										case 6:
											latch2b &= 0xFF00;
											latch2b |= 0xFF & pokeVal;
											break;

										case 7:
											latch2b &= 0xFF;
											latch2b |= ( 0xFF & pokeVal ) << 8;

										case 13:
											if( ( pokeVal & 0x01 ) != 0 )
											{
												if( ( pokeVal & 0x80 ) != 0 ) icr2set |= 1;
												else icr2set &= 254;
											}
											if( ( pokeVal & 0x02 ) != 0 )
											{
												if( ( pokeVal & 0x80 ) != 0 ) icr2set |= 2;
												else icr2set &= 253;
											}
											if( ( pokeVal & 0x04 ) != 0 )
											{
												if( ( pokeVal & 0x80 ) != 0 ) icr2set |= 4;
												else icr2set &= 251;
											}
											if( ( pokeVal & 0x08 ) != 0 )
											{
												if( ( pokeVal & 0x80 ) != 0 ) icr2set |= 8;
												else icr2set &= 247;
											}
											if( ( pokeVal & 0x10 ) != 0 )
											{
												if( ( pokeVal & 0x80 ) != 0 ) icr2set |= 16;
												else icr2set &= 239;
											}
											break;

										case 14:
											if( ( pokeVal & 0x10 ) != 0 )
											{
												t2a = regs[ regsOff + 0xD04 ] = (byte)latch2a;
												if( ( pokeVal & 1 ) != 0 ) enable2a = true;
												else enable2a = false;
											}
											break;

										case 15:
											if( ( pokeVal & 0x10 ) != 0 )
											{
												t2b = regs[ regsOff + 0xD06 ] = (byte)latch2b;
												if( ( pokeVal & 1 ) != 0 ) enable2b = true;
												else enable2b = false;
											}
											break;
									}
								}
							}
						}

						pokeDest = -1;
					}
				}

				if( enable1a )
				{
					if( t1a == 0 )
					{
						t1a = (byte)latch1a;

						if( ( regs[ regsOff + 0xC0E ] & 0x09 ) == 0x09 ) regs[ regsOff + 0xC0E ]--;

						if( ( icr1set & 0x01 ) != 0 )
						{
							irq = true;
							regs[ regsOff + 0xC0D ] = (byte)0x81;
						}
						else regs[ regsOff + 0xC0D ] |= 1;

						if( ( regs[ regsOff + 0xC0F ] & 0x60 ) == 0x40 ) regs[ regsOff + 0xC06 ] = --t1b;
					}

					regs[ regsOff + 0xC04 ] = --t1a;
				}

				if( enable1b )
				{
					if( t1b == 0 )
					{
						t1b = regs[ regsOff + 0xC06 ] = (byte)latch1b;

						if( ( regs[ regsOff + 0xC0F ] & 0x09 ) == 0x09 ) regs[ regsOff + 0xC0F ]--;

						if( ( icr1set & 0x02 ) != 0 )
						{
							irq = true;
							regs[ regsOff + 0xC0D ] = (byte)0x82;
						}
						else regs[ regsOff + 0xC0D ] |= 2;
					}
					else if( ( regs[ regsOff + 0xC0F ] & 0x60 ) == 0 )
					{
						regs[ regsOff + 0xC06 ] = --t1b;
					}
				}

				if( enable2a )
				{
					if( t2a == 0 )
					{
						t2a = (byte)latch2a;

						if( ( regs[ regsOff + 0xD0E ] & 0x09 ) == 0x09 ) regs[ regsOff + 0xD0E ]--;

						if( ( icr2set & 0x01 ) != 0 )
						{
							nmi = true;
							regs[ regsOff + 0xD0D ] = (byte)0x81;
						}
						else regs[ regsOff + 0xD0D ] |= 1;

						if( ( regs[ regsOff + 0xD0F ] & 0x60 ) == 0x40 ) regs[ regsOff + 0xD06 ] = --t2b;
					}

					regs[ regsOff + 0xD04 ] = --t2a;
				}

				if( enable2b )
				{
					if( t2b == 0 )
					{
						t2b = regs[ regsOff + 0xD06 ] = (byte)latch2b;

						if( ( regs[ regsOff + 0xD0F ] & 0x09 ) == 0x09 ) regs[ regsOff + 0xD0F ]--;

						if( ( icr2set & 0x02 ) != 0 )
						{
							nmi = true;
							regs[ regsOff + 0xD0D ] = (byte)0x82;
						}
						else regs[ regsOff + 0xD0D ] |= 2;
					}
					else if( ( regs[ regsOff + 0xD0F ] & 0x60 ) == 0 )
					{
						regs[ regsOff + 0xD06 ] = --t2b;
					}
				}
			}
		}

		int pos = 0x0400;

		for( int y=0; y<25; y++ )
			for( int x=0; x<40; x++ )
			{
				putCBMChar( 0xFF & peekMem[ pos ], x, y, regs[ regsOff + 0x400 + pos ], 0xF & regs[ regsOff + 0x21 ] );
				pos++;
			}
	}

	private final void ADC( byte gen1 )
	{
		int c;
		if( carry_flag ) c = 1;
		else c = 0;

		if( decimal_flag )
		{
			int k = ( a_reg & 0xF ) + ( gen1 & 0xF ) + c;

			if( ( k & 0xFF ) >= 0xA ) k = ( k & 0xFF00 ) + ( ( k + 0x6 ) & 0xFF );
			if( ( k & 0xFF ) >= 0x20 ) k = ( k & 0xFF0F ) + 0x10;

			k += ( a_reg & 0xF0 ) + ( gen1 & 0xF0 );

			boolean n_flag = ( k & 0x80 ) != 0;
			boolean z_flag = ( 0xFF & ( ( 0xFF & a_reg ) + ( 0xFF & gen1 ) + c ) ) == 0;
			if( n_flag && z_flag ) System.out.println( "negative zero fuckup in ADC" );

			neg_zero_flags = (byte)k;
			if( z_flag ) neg_zero_flags = 0;
			else if( neg_zero_flags == 0 ) neg_zero_flags++;

			overflow_flag = ( ~( ( 0xFF & a_reg ) ^ ( 0xFF & gen1 ) ) & ( ( 0xFF & a_reg ) ^ ( 0xFF & k ) ) & 0x80 ) != 0;

			if( carry_flag = k >= 0xA0 )
				k += 0x60;

			a_reg = (byte)k;
		}
		else
		{
			int k = ( 0xFF & (int)a_reg ) + ( 0xFF & (int)gen1 ) + c;

			neg_zero_flags = (byte)k;
			overflow_flag = ( ~( ( 0xFF & a_reg ) ^ ( 0xFF & gen1 ) ) & ( ( 0xFF & a_reg ) ^ ( 0xFF & k ) ) & 0x80 ) != 0;
			carry_flag = ( k & 0xFF00 ) != 0;

			a_reg = (byte)k;
		}
	}

	private final void SBC( byte gen1 )
	{
		int c;
		if( !carry_flag ) c = 1;
		else c = 0;

		if( decimal_flag )
		{
			int k = ( a_reg & 0xF ) + 0x100;
			k -= ( gen1 & 0xF ) + c;
			if( k < 0x100 ) k -= 6;
			if( k < 0xF0 ) k += 0x10;
			k += a_reg & 0xF0;
			k -= gen1 & 0xF0;

			boolean n_flag = ( k & 0x80 ) != 0;
			boolean z_flag = ( 0xFF & ( ( 0xFF & a_reg ) - ( 0xFF & gen1 ) - c ) ) == 0;
			if( n_flag && z_flag ) System.out.println( "negative zero fuckup in SBC" );

			neg_zero_flags = (byte)k;
			if( z_flag ) neg_zero_flags = 0;
			else if( neg_zero_flags == 0 ) neg_zero_flags++;

			overflow_flag = ( ~( ( 0xFF & k ) ^ ( 0xFF & gen1 ) ) & ( ( 0xFF & a_reg ) ^ ( 0xFF & gen1 ) ) & 0x80 ) != 0;

			carry_flag = ( k & 0xFF00 ) != 0;
			if( !carry_flag ) k = ( k & 0xFF00 ) + ( 0xFF & ( ( k & 0xFF ) - 0x60 ) );

			a_reg = (byte)k;
		}
		else
		{
			int k = 0x100 + ( 0xFF & a_reg ) - ( 0xFF & gen1 ) - c;

			neg_zero_flags = (byte)k;
			overflow_flag = ( ~( ( 0xFF & k ) ^ ( 0xFF & gen1 ) ) & ( ( 0xFF & a_reg ) ^ ( 0xFF & gen1 ) ) & 0x80 ) != 0;
			carry_flag = ( k & 0xFF00 ) != 0;

			a_reg = (byte)k;
		}
	}

	private final int deek( int address )
	{
		return ( 0xFF & peekMem[ address ] ) + ( ( 0xFF & peekMem[ address + 1 ] ) << 8 );
	}

	private final void putCBMChar( int letter, int xp, int yp, int fore, int back )
	{
		byte foreb = (byte)fore;
		byte backb = (byte)back;

		int place = xp * 8 + 320 * yp * 8;

		for( int y=0; y<8; y++ )
		{
			int o = 0xFF & charMem[ letter * 8 + y ];
			int pos = 128;

			for( int x=0; x<8; x++ )
			{
				byte col;

				if( o >= pos )
				{
					o -= pos;
					col = foreb;
				}
				else col = backb;

				pixelBuffer[ x + 320 * y + place ] = palette[ col ];

				pos = pos >> 1;
			}
		}
	}

	private final void putCBMStr( String string, int xp, int yp, int fore, int back )
	{
		int len = string.length();
		if( xp + len > 40 ) len = 40 - xp;

		for( int i=0; i<len; i++ )
			putCBMChar( string.charAt( i ) & 63, xp++, yp, fore, back );
	}

	private final int putInst( int loc, int y )
	{
		putCBMStr( hexToString( loc, 4 ), 0, y, 1, 0 );

		putCBMStr( hexToString( peekMem[ loc ], 2 ), 5, y, 2, 0 );
		putCBMStr( hexToString( peekMem[ loc + 1 ], 2 ), 8, y, 2, 0 );
		putCBMStr( hexToString( peekMem[ loc + 2 ], 2 ), 11, y, 2, 0 );

		String str = instNames[ 0xFF & peekMem[ loc ] ];

		int i = str.indexOf( '*' );
		if( i >= 0 )
		{
			str = str.substring( 0, i ) + hexToString( loc + 2 + peekMem[ loc + 1 ], 4 ) + str.substring( i + 2 );
			i = 2;
		}
		else
		{
			i = str.indexOf( 'a' );
			if( i >= 0 )
			{
				str = str.substring( 0, i ) + hexToString( peekMem[ loc + 1 ], 2 ) + str.substring( i + 1 );

				i = str.indexOf( 'b' );
				if( i >= 0 )
				{
					str = str.substring( 0, i ) + hexToString( peekMem[ loc + 2 ], 2 ) + str.substring( i + 1 );
					i = 3;
				}
				else i = 2;
			}
			else i = 1;
		}

		putCBMStr( str, 14, y, 1, 0 );

		return i;
	}

	private final String hexToString( int val, int len )
	{
		String str = Integer.toHexString( val ).toUpperCase();

		if( str.length() > len ) str = str.substring( str.length() - len );
		else while( str.length() < len ) str = "0" + str;

		return str;
	}

	private final String instNames[] =
	{
/*0x00*/ "BRK", 
/*0x01*/ "ORA ($a,X)", 
/*0x02*/ "???", 
/*0x03*/ "??? ($a,X)", 
/*0x04*/ "??? $a", 
/*0x05*/ "ORA $a", 
/*0x06*/ "ASL $a", 
/*0x07*/ "??? $a", 
/*0x08*/ "PHP", 
/*0x09*/ "ORA #$a", 
/*0x0A*/ "ASL", 
/*0x0B*/ "??? #$a", 
/*0x0C*/ "??? $ba", 
/*0x0D*/ "ORA $ba", 
/*0x0E*/ "ASL $ba", 
/*0x0F*/ "??? $ba", 
/*0x10*/ "BPL $*a", 
/*0x11*/ "ORA ($a),Y", 
/*0x12*/ "???", 
/*0x13*/ "??? ($a),Y", 
/*0x14*/ "??? $a,X", 
/*0x15*/ "ORA $a,X", 
/*0x16*/ "ASL $a,X", 
/*0x17*/ "??? $a,X", 
/*0x18*/ "CLC", 
/*0x19*/ "ORA $ba,Y", 
/*0x1A*/ "???", 
/*0x1B*/ "??? $ba,Y", 
/*0x1C*/ "??? $a", 
/*0x1D*/ "ORA $ba,X", 
/*0x1E*/ "ASL $ba,X", 
/*0x1F*/ "??? $ba,X", 
/*0x20*/ "JSR $ba", 
/*0x21*/ "AND ($a,X)", 
/*0x22*/ "NOP", 
/*0x23*/ "??? ($a,X)", 
/*0x24*/ "BIT $a", 
/*0x25*/ "AND $a", 
/*0x26*/ "ROL $a", 
/*0x27*/ "??? $a", 
/*0x28*/ "PLP", 
/*0x29*/ "AND #$a", 
/*0x2A*/ "ROL", 
/*0x2B*/ "??? #$a", 
/*0x2C*/ "BIT $ba", 
/*0x2D*/ "AND $ba", 
/*0x2E*/ "ROL $ba", 
/*0x2F*/ "??? $ba", 
/*0x30*/ "BMI $*a", 
/*0x31*/ "AND ($a),Y", 
/*0x32*/ "???", 
/*0x33*/ "??? ($a),Y", 
/*0x34*/ "??? $a,X", 
/*0x35*/ "AND $a,X", 
/*0x36*/ "ROL $a,X", 
/*0x37*/ "??? $a,X", 
/*0x38*/ "SEC", 
/*0x39*/ "AND $ba,Y", 
/*0x3A*/ "???", 
/*0x3B*/ "??? $ba,Y", 
/*0x3C*/ "??? $ba,X", 
/*0x3D*/ "AND $ba,X", 
/*0x3E*/ "ROL $ba,X", 
/*0x3F*/ "??? $ba,X", 
/*0x40*/ "RTI", 
/*0x41*/ "EOR ($a,X)", 
/*0x42*/ "???", 
/*0x43*/ "??? ($a,X)", 
/*0x44*/ "??? $a", 
/*0x45*/ "EOR $a", 
/*0x46*/ "LSR $a", 
/*0x47*/ "??? $a", 
/*0x48*/ "PHA", 
/*0x49*/ "EOR #$a", 
/*0x4A*/ "LSR", 
/*0x4B*/ "??? #$a", 
/*0x4C*/ "JMP $ba", 
/*0x4D*/ "EOR $ba", 
/*0x4E*/ "LSR $ba", 
/*0x4F*/ "??? $ba", 
/*0x50*/ "BVC $*a", 
/*0x51*/ "EOR ($a),Y", 
/*0x52*/ "???", 
/*0x53*/ "??? ($a),Y", 
/*0x54*/ "??? $a,X", 
/*0x55*/ "EOR $a,X", 
/*0x56*/ "LSR $a,X", 
/*0x57*/ "??? $a,X", 
/*0x58*/ "CLI", 
/*0x59*/ "EOR $ba,Y", 
/*0x5A*/ "???", 
/*0x5B*/ "??? $ba,Y", 
/*0x5C*/ "??? $ba,X", 
/*0x5D*/ "EOR $ba,X", 
/*0x5E*/ "LSR $ba,X", 
/*0x5F*/ "??? $ba,X", 
/*0x60*/ "RTS", 
/*0x61*/ "ADC ($a,X)", 
/*0x62*/ "???", 
/*0x63*/ "??? ($a,X)", 
/*0x64*/ "??? $a", 
/*0x65*/ "ADC $a", 
/*0x66*/ "ROR $a", 
/*0x67*/ "??? $a", 
/*0x68*/ "PLA", 
/*0x69*/ "ADC #$a", 
/*0x6A*/ "ROR", 
/*0x6B*/ "??? #$a", 
/*0x6C*/ "JMP ($ba)", 
/*0x6D*/ "ADC $ba", 
/*0x6E*/ "ROR $ba", 
/*0x6F*/ "??? $ba", 
/*0x70*/ "BVS $*a", 
/*0x71*/ "ADC ($a),Y", 
/*0x72*/ "???", 
/*0x73*/ "??? ($a),Y", 
/*0x74*/ "??? $a,X", 
/*0x75*/ "ADC $a,X", 
/*0x76*/ "ROR $a,X", 
/*0x77*/ "??? $a,X", 
/*0x78*/ "SEI", 
/*0x79*/ "ADC $ba,Y", 
/*0x7A*/ "???", 
/*0x7B*/ "??? $ba,Y", 
/*0x7C*/ "??? $ba,X", 
/*0x7D*/ "ADC $ba,X", 
/*0x7E*/ "ROR $ba,X", 
/*0x7F*/ "??? $ba,X", 
/*0x80*/ "??? #$a", 
/*0x81*/ "STA ($a,X)", 
/*0x82*/ "??? #$a", 
/*0x83*/ "??? ($a,X)", 
/*0x84*/ "STY $a", 
/*0x85*/ "STA $a", 
/*0x86*/ "STX $a", 
/*0x87*/ "??? $a", 
/*0x88*/ "DEY", 
/*0x89*/ "??? #$a", 
/*0x8A*/ "TXA", 
/*0x8B*/ "??? #$a", 
/*0x8C*/ "STY $ba", 
/*0x8D*/ "STA $ba", 
/*0x8E*/ "STX $ba", 
/*0x8F*/ "??? $ba", 
/*0x90*/ "BCC $*a", 
/*0x91*/ "STA ($a),Y", 
/*0x92*/ "???", 
/*0x93*/ "??? ($a),Y", 
/*0x94*/ "STY $a,X", 
/*0x95*/ "STA $a,X", 
/*0x96*/ "STX $a,Y", 
/*0x97*/ "??? $a,Y", 
/*0x98*/ "TYA", 
/*0x99*/ "STA $ba,Y", 
/*0x9A*/ "TXS", 
/*0x9B*/ "??? $ba,Y", 
/*0x9C*/ "??? $ba,X", 
/*0x9D*/ "STA $ba,X", 
/*0x9E*/ "??? $ba,Y", 
/*0x9F*/ "??? $ba,Y", 
/*0xA0*/ "LDY #$a", 
/*0xA1*/ "LDA ($a,X)", 
/*0xA2*/ "LDX #$a", 
/*0xA3*/ "??? ($a,X)", 
/*0xA4*/ "LDY $a", 
/*0xA5*/ "LDA $a", 
/*0xA6*/ "LDX $a", 
/*0xA7*/ "??? $a", 
/*0xA8*/ "TAY", 
/*0xA9*/ "LDA #$a", 
/*0xAA*/ "TAX", 
/*0xAB*/ "??? #$a", 
/*0xAC*/ "LDY $ba", 
/*0xAD*/ "LDA $ba", 
/*0xAE*/ "LDX $ba", 
/*0xAF*/ "??? $ba", 
/*0xB0*/ "BCS $*a", 
/*0xB1*/ "LDA ($a),Y", 
/*0xB2*/ "???", 
/*0xB3*/ "??? ($a),Y", 
/*0xB4*/ "LDY $a,X", 
/*0xB5*/ "LDA $a,X", 
/*0xB6*/ "LDX $a,Y", 
/*0xB7*/ "??? $a,Y", 
/*0xB8*/ "CLV", 
/*0xB9*/ "LDA $ba,Y", 
/*0xBA*/ "TSX", 
/*0xBB*/ "??? $ba,Y", 
/*0xBC*/ "LDY $ba,X", 
/*0xBD*/ "LDA $ba,X", 
/*0xBE*/ "LDX $ba,Y", 
/*0xBF*/ "??? $ba,Y", 
/*0xC0*/ "CPY #$a", 
/*0xC1*/ "CMP ($a,X)", 
/*0xC2*/ "??? #$a", 
/*0xC3*/ "??? ($a,X)", 
/*0xC4*/ "CPY $a", 
/*0xC5*/ "CMP $a", 
/*0xC6*/ "DEC $a", 
/*0xC7*/ "??? $a", 
/*0xC8*/ "INY", 
/*0xC9*/ "CMP #$a", 
/*0xCA*/ "DEX", 
/*0xCB*/ "??? #$a", 
/*0xCC*/ "CPY $ba", 
/*0xCD*/ "CMP $ba", 
/*0xCE*/ "DEC $ba", 
/*0xCF*/ "??? $ba", 
/*0xD0*/ "BNE $*a", 
/*0xD1*/ "CMP ($a),Y", 
/*0xD2*/ "???", 
/*0xD3*/ "??? ($a),Y", 
/*0xD4*/ "??? $a,X", 
/*0xD5*/ "CMP $a,X", 
/*0xD6*/ "DEC $a,X", 
/*0xD7*/ "??? $a,X", 
/*0xD8*/ "CLD", 
/*0xD9*/ "CMP $ba,Y", 
/*0xDA*/ "???", 
/*0xDB*/ "??? $ba,Y", 
/*0xDC*/ "??? $ba,X", 
/*0xDD*/ "CMP $ba,X", 
/*0xDE*/ "DEC $ba,X", 
/*0xDF*/ "??? $ba,X", 
/*0xE0*/ "CPX #$a", 
/*0xE1*/ "SBC ($a,X)", 
/*0xE2*/ "??? #$a", 
/*0xE3*/ "??? ($a,X)", 
/*0xE4*/ "CPX $a", 
/*0xE5*/ "SBC $a", 
/*0xE6*/ "INC $a", 
/*0xE7*/ "??? $a", 
/*0xE8*/ "INX", 
/*0xE9*/ "SBC #$a", 
/*0xEA*/ "NOP", 
/*0xEB*/ "??? #$a", 
/*0xEC*/ "CPX $ba", 
/*0xED*/ "SBC $ba", 
/*0xEE*/ "INC $ba", 
/*0xEF*/ "??? $ba", 
/*0xF0*/ "BEQ $*a", 
/*0xF1*/ "SBC ($a),Y", 
/*0xF2*/ "???", 
/*0xF3*/ "??? ($a),Y", 
/*0xF4*/ "??? $a,X", 
/*0xF5*/ "SBC $a,X", 
/*0xF6*/ "INC $a,X", 
/*0xF7*/ "??? $a,X", 
/*0xF8*/ "SED", 
/*0xF9*/ "SBC $ba,Y", 
/*0xFA*/ "???", 
/*0xFB*/ "??? $ba,Y", 
/*0xFC*/ "??? $ba,X", 
/*0xFD*/ "SBC $ba,X", 
/*0xFE*/ "INC $ba,X", 
/*0xFF*/ "??? $ba,X" 
}; 

}

