// **************************************************************************
// **           COME BACK 64 - A FREEWARE COMMODORE 64 EMULATOR            **
// **          WWW.COMEBACK.C64.ORG             JHF@FAIRLIGHT.TO           **
// **************************************************************************
// **                 THIS IS VERSION ALPHA 1 FOR UNIX                     ** 
// **************************************************************************
// ** MAIN PROGRAMMERS      : JOHAN FITIE AND BRAD MARTIN                  **
// ** ROUTINE CONTRIBUTORS  : STEVEN H. DON - SOME SOUND FIXES             **
// **                         MASSIMILIANO AGOSTINELLI - CARTRIDGE LOADER  **
// ** SUPPORT               : PONTUS BERG (BACCHUS/FAIRLIGHT)              **
// **                         MARKO MAKELA (AUTHOR OF VARIOUS C64 DOCS)    **
// **                         PER HAKAN SUNDELL (AUTHOR OF CCS64)          **
// **                         MICHAEL SCHWENDT (AUTHOR OF SIDPLAY)         **
// **                         WOLFGANG LORENZ (AUTHOR OF PC64)             **
// **                         JOE FORSTER (STA, AUTHOR OF STAR COMMANDER)  **
// **                         PAUL TOTH (AUTHOR OF CBM64)                  **
// **                         DAAN VAN YPEREN (DYPER)                      ** 
// **                                                                      **
// ** WIN32 PORT            : MARTIN DUFOUR (VIP/DCB)                      **
// **                         WORK CONTINUED BY THE WIN32 PORT TEAM WITH   **
// **                         BETA 2                                       **
// **                                                                      **
// ** WINDOWS CE PORT       : DOMENICO DATO (DATO@DI.UNIPI.IT)             **
// **                                                                      **
// ** UNIX/X-WINDOWS PORT   : DOMENICO DATO (DATO@DI.UNIPI.IT)             **
// **                         (THANKS TO MARAT FAYZULLIN FOR HIS EMULIB)   **
// **                                                                      **
// **************************************************************************
// **  THE SOURCE AND BINARY OF COME BACK 64 ARE FREELY DISTRIBUTABLE, AS  **
// ** LONG AS THEY ARE KEPT INTACT AND ARE NOT CHANGED. THE LATEST VERSION **
// **         IS AVAILABLE FROM HTTP://WWW.CLASSICGAMING.COM/CB64          **
// **************************************************************************
// ** IF YOU MAKE A LINK TO THE COME BACK 64 PAGE ON YOUR WEB-SITE, OR IF  **
// ** YOU WANT TO MIRROR CB 64, YOU HEREBY HAVE MY PERMISSION, AS LONG AS  **
// **          YOU INFORM ME ABOUT THE URL WHERE THE LINKS IS ON.          **
// **************************************************************************

#include "cb64.h"

char * opcodes[256] =
{
/*0x00*/ "BRK",
/*0x01*/ "ORA ($a,X)",
/*0x02*/ "???",
/*0x03*/ "??? ($a,X)",
/*0x04*/ "??? $a",
/*0x05*/ "ORA $a",
/*0x06*/ "ASL $a",
/*0x07*/ "??? $a",
/*0x08*/ "PHP",
/*0x09*/ "ORA #$a",
/*0x0A*/ "ASL",
/*0x0B*/ "??? #$a",
/*0x0C*/ "??? $ba",
/*0x0D*/ "ORA $ba",
/*0x0E*/ "ASL $ba",
/*0x0F*/ "??? $ba",
/*0x10*/ "BPL $*a",
/*0x11*/ "ORA ($a),Y",
/*0x12*/ "???",
/*0x13*/ "??? ($a),Y",
/*0x14*/ "??? $a,X",
/*0x15*/ "ORA $a,X",
/*0x16*/ "ASL $a,X",
/*0x17*/ "??? $a,X",
/*0x18*/ "CLC",
/*0x19*/ "ORA $ba,Y",
/*0x1A*/ "???",
/*0x1B*/ "??? $ba,Y",
/*0x1C*/ "??? $a",
/*0x1D*/ "ORA $ba,X",
/*0x1E*/ "ASL $ba,X",
/*0x1F*/ "??? $ba,X",
/*0x20*/ "JSR $ba",
/*0x21*/ "AND ($a,X)",
/*0x22*/ "NOP",
/*0x23*/ "??? ($a,X)",
/*0x24*/ "BIT $a",
/*0x25*/ "AND $a",
/*0x26*/ "ROL $a",
/*0x27*/ "??? $a",
/*0x28*/ "PLP",
/*0x29*/ "AND #$a",
/*0x2A*/ "ROL",
/*0x2B*/ "??? #$a",
/*0x2C*/ "BIT $ba",
/*0x2D*/ "AND $ba",
/*0x2E*/ "ROL $ba",
/*0x2F*/ "??? $ba",
/*0x30*/ "BMI $*a",
/*0x31*/ "AND ($a),Y",
/*0x32*/ "???",
/*0x33*/ "??? ($a),Y",
/*0x34*/ "??? $a,X",
/*0x35*/ "AND $a,X",
/*0x36*/ "ROL $a,X",
/*0x37*/ "??? $a,X",
/*0x38*/ "SEC",
/*0x39*/ "AND $ba,Y",
/*0x3A*/ "???",
/*0x3B*/ "??? $ba,Y",
/*0x3C*/ "??? $ba,X",
/*0x3D*/ "AND $ba,X",
/*0x3E*/ "ROL $ba,X",
/*0x3F*/ "??? $ba,X",
/*0x40*/ "RTI",
/*0x41*/ "EOR ($a,X)",
/*0x42*/ "???",
/*0x43*/ "??? ($a,X)",
/*0x44*/ "??? $a",
/*0x45*/ "EOR $a",
/*0x46*/ "LSR $a",
/*0x47*/ "??? $a",
/*0x48*/ "PHA",
/*0x49*/ "EOR #$a",
/*0x4A*/ "LSR",
/*0x4B*/ "??? #$a",
/*0x4C*/ "JMP $ba",
/*0x4D*/ "EOR $ba",
/*0x4E*/ "LSR $ba",
/*0x4F*/ "??? $ba",
/*0x50*/ "BVC $*a",
/*0x51*/ "EOR ($a),Y",
/*0x52*/ "???",
/*0x53*/ "??? ($a),Y",
/*0x54*/ "??? $a,X",
/*0x55*/ "EOR $a,X",
/*0x56*/ "LSR $a,X",
/*0x57*/ "??? $a,X",
/*0x58*/ "CLI",
/*0x59*/ "EOR $ba,Y",
/*0x5A*/ "???",
/*0x5B*/ "??? $ba,Y",
/*0x5C*/ "??? $ba,X",
/*0x5D*/ "EOR $ba,X",
/*0x5E*/ "LSR $ba,X",
/*0x5F*/ "??? $ba,X",
/*0x60*/ "RTS",
/*0x61*/ "ADC ($a,X)",
/*0x62*/ "???",
/*0x63*/ "??? ($a,X)",
/*0x64*/ "??? $a",
/*0x65*/ "ADC $a",
/*0x66*/ "ROR $a",
/*0x67*/ "??? $a",
/*0x68*/ "PLA",
/*0x69*/ "ADC #$a",
/*0x6A*/ "ROR",
/*0x6B*/ "??? #$a",
/*0x6C*/ "JMP ($ba)",
/*0x6D*/ "ADC $ba",
/*0x6E*/ "ROR $ba",
/*0x6F*/ "??? $ba",
/*0x70*/ "BVS $*a",
/*0x71*/ "ADC ($a),Y",
/*0x72*/ "???",
/*0x73*/ "??? ($a),Y",
/*0x74*/ "??? $a,X",
/*0x75*/ "ADC $a,X",
/*0x76*/ "ROR $a,X",
/*0x77*/ "??? $a,X",
/*0x78*/ "SEI",
/*0x79*/ "ADC $ba,Y",
/*0x7A*/ "???",
/*0x7B*/ "??? $ba,Y",
/*0x7C*/ "??? $ba,X",
/*0x7D*/ "ADC $ba,X",
/*0x7E*/ "ROR $ba,X",
/*0x7F*/ "??? $ba,X",
/*0x80*/ "??? #$a",
/*0x81*/ "STA ($a,X)",
/*0x82*/ "??? #$a",
/*0x83*/ "??? ($a,X)",
/*0x84*/ "STY $a",
/*0x85*/ "STA $a",
/*0x86*/ "STX $a",
/*0x87*/ "??? $a",
/*0x88*/ "DEY",
/*0x89*/ "??? #$a",
/*0x8A*/ "TXA",
/*0x8B*/ "??? #$a",
/*0x8C*/ "STY $ba",
/*0x8D*/ "STA $ba",
/*0x8E*/ "STX $ba",
/*0x8F*/ "??? $ba",
/*0x90*/ "BCC $*a",
/*0x91*/ "STA ($a),Y",
/*0x92*/ "???",
/*0x93*/ "??? ($a),Y",
/*0x94*/ "STY $a,X",
/*0x95*/ "STA $a,X",
/*0x96*/ "STX $a,Y",
/*0x97*/ "??? $a,Y",
/*0x98*/ "TYA",
/*0x99*/ "STA $ba,Y",
/*0x9A*/ "TXS",
/*0x9B*/ "??? $ba,Y",
/*0x9C*/ "??? $ba,X",
/*0x9D*/ "STA $ba,X",
/*0x9E*/ "??? $ba,Y",
/*0x9F*/ "??? $ba,Y",
/*0xA0*/ "LDY #$a",
/*0xA1*/ "LDA ($a,X)",
/*0xA2*/ "LDX #$a",
/*0xA3*/ "??? ($a,X)",
/*0xA4*/ "LDY $a",
/*0xA5*/ "LDA $a",
/*0xA6*/ "LDX $a",
/*0xA7*/ "??? $a",
/*0xA8*/ "TAY",
/*0xA9*/ "LDA #$a",
/*0xAA*/ "TAX",
/*0xAB*/ "??? #$a",
/*0xAC*/ "LDY $ba",
/*0xAD*/ "LDA $ba",
/*0xAE*/ "LDX $ba",
/*0xAF*/ "??? $ba",
/*0xB0*/ "BCS $*a",
/*0xB1*/ "LDA ($a),Y",
/*0xB2*/ "???",
/*0xB3*/ "??? ($a),Y",
/*0xB4*/ "LDY $a,X",
/*0xB5*/ "LDA $a,X",
/*0xB6*/ "LDX $a,Y",
/*0xB7*/ "??? $a,Y",
/*0xB8*/ "CLV",
/*0xB9*/ "LDA $ba,Y",
/*0xBA*/ "TSX",
/*0xBB*/ "??? $ba,Y",
/*0xBC*/ "LDY $ba,X",
/*0xBD*/ "LDA $ba,X",
/*0xBE*/ "LDX $ba,Y",
/*0xBF*/ "??? $ba,Y",
/*0xC0*/ "CPY #$a",
/*0xC1*/ "CMP ($a,X)",
/*0xC2*/ "??? #$a",
/*0xC3*/ "??? ($a,X)",
/*0xC4*/ "CPY $a",
/*0xC5*/ "CMP $a",
/*0xC6*/ "DEC $a",
/*0xC7*/ "??? $a",
/*0xC8*/ "INY",
/*0xC9*/ "CMP #$a",
/*0xCA*/ "DEX",
/*0xCB*/ "??? #$a",
/*0xCC*/ "CPY $ba",
/*0xCD*/ "CMP $ba",
/*0xCE*/ "DEC $ba",
/*0xCF*/ "??? $ba",
/*0xD0*/ "BNE $*a",
/*0xD1*/ "CMP ($a),Y",
/*0xD2*/ "???",
/*0xD3*/ "??? ($a),Y",
/*0xD4*/ "??? $a,X",
/*0xD5*/ "CMP $a,X",
/*0xD6*/ "DEC $a,X",
/*0xD7*/ "??? $a,X",
/*0xD8*/ "CLD",
/*0xD9*/ "CMP $ba,Y",
/*0xDA*/ "???",
/*0xDB*/ "??? $ba,Y",
/*0xDC*/ "??? $ba,X",
/*0xDD*/ "CMP $ba,X",
/*0xDE*/ "DEC $ba,X",
/*0xDF*/ "??? $ba,X",
/*0xE0*/ "CPX #$a",
/*0xE1*/ "SBC ($a,X)",
/*0xE2*/ "??? #$a",
/*0xE3*/ "??? ($a,X)",
/*0xE4*/ "CPX $a",
/*0xE5*/ "SBC $a",
/*0xE6*/ "INC $a",
/*0xE7*/ "??? $a",
/*0xE8*/ "INX",
/*0xE9*/ "SBC #$a",
/*0xEA*/ "NOP",
/*0xEB*/ "??? #$a",
/*0xEC*/ "CPX $ba",
/*0xED*/ "SBC $ba",
/*0xEE*/ "INC $ba",
/*0xEF*/ "??? $ba",
/*0xF0*/ "BEQ $*a",
/*0xF1*/ "SBC ($a),Y",
/*0xF2*/ "???",
/*0xF3*/ "??? ($a),Y",
/*0xF4*/ "??? $a,X",
/*0xF5*/ "SBC $a,X",
/*0xF6*/ "INC $a,X",
/*0xF7*/ "??? $a,X",
/*0xF8*/ "SED",
/*0xF9*/ "SBC $ba,Y",
/*0xFA*/ "???",
/*0xFB*/ "??? $ba,Y",
/*0xFC*/ "??? $ba,X",
/*0xFD*/ "SBC $ba,X",
/*0xFE*/ "INC $ba,X",
/*0xFF*/ "??? $ba,X"
};

BYTE ORIGINAL64B[8193] =
{
	'','','{','','C','B','M','B','A','S','I','C','0','','A','',29,'',
	'','','','','','','','',5,'','','','','','p','',39,'',28,
	'','','','','',':','','.','','J','',',','','g','','U','','d',
	'','','','#','','','','','','V','','','',']','','','',')',
	'','','','','','z','','A','','9','','','','X','',16,3,'}','',
	'','','q','','','','','','','','d','','k','','','',14,'',
	13,'','|','','e','','','','','','','',0,'',',','','7','','y',
	'i','','y','R','','{','*','','{',17,'','','z','','P','','','F',
	'','','}','','','Z','','','d',21,'','E','N','','F','O','','N',
	'E','X','','D','A','T','','I','N','P','U','T','','I','N','P','U','',
	'D','I','','R','E','A','','L','E','','G','O','T','','R','U','','I',
	'','R','E','S','T','O','R','','G','O','S','U','','R','E','T','U','R',
	'','R','E','','S','T','O','','O','','W','A','I','','L','O','A','',
	'S','A','V','','V','E','R','I','F','','D','E','','P','O','K','','P',
	'R','I','N','T','','P','R','I','N','','C','O','N','','L','I','S','',
	'C','L','','C','M','','S','Y','','O','P','E','','C','L','O','S','',
	'G','E','','N','E','','T','A','B','','T','','F','','S','P','C','',
	'T','H','E','','N','O','','S','T','E','','','','','','','A','N',
	'','O','','','','','S','G','','I','N','','A','B','','U','S','',
	'F','R','','P','O','','S','Q','','R','N','','L','O','','E','X','',
	'C','O','','S','I','','T','A','','A','T','','P','E','E','','L','E',
	'','S','T','R','','V','A','','A','S','','C','H','R','','L','E','F',
	'T','','R','I','G','H','T','','M','I','D','','G','',0,'T','O','O',
	' ','M','A','N','Y',' ','F','I','L','E','','F','I','L','E',' ','O','P',
	'E','','F','I','L','E',' ','N','O','T',' ','O','P','E','','F','I','L',
	'E',' ','N','O','T',' ','F','O','U','N','','D','E','V','I','C','E',' ',
	'N','O','T',' ','P','R','E','S','E','N','','N','O','T',' ','I','N','P',
	'U','T',' ','F','I','L','','N','O','T',' ','O','U','T','P','U','T',' ',
	'F','I','L','','M','I','S','S','I','N','G',' ','F','I','L','E',' ','N',
	'A','M','','I','L','L','E','G','A','L',' ','D','E','V','I','C','E',' ',
	'N','U','M','B','E','','N','E','X','T',' ','W','I','T','H','O','U','T',
	' ','F','O','','S','Y','N','T','A','','R','E','T','U','R','N',' ','W',
	'I','T','H','O','U','T',' ','G','O','S','U','','O','U','T',' ','O','F',
	' ','D','A','T','','I','L','L','E','G','A','L',' ','Q','U','A','N','T',
	'I','T','','O','V','E','R','F','L','O','','O','U','T',' ','O','F',' ',
	'M','E','M','O','R','','U','N','D','E','F',39,'D',' ','S','T','A','T',
	'E','M','E','N','','B','A','D',' ','S','U','B','S','C','R','I','P','',
	'R','E','D','I','M',39,'D',' ','A','R','R','A','','D','I','V','I','S',
	'I','O','N',' ','B','Y',' ','Z','E','R','','I','L','L','E','G','A','L',
	' ','D','I','R','E','C','','T','Y','P','E',' ','M','I','S','M','A','T',
	'C','','S','T','R','I','N','G',' ','T','O','O',' ','L','O','N','','F',
	'I','L','E',' ','D','A','T','','F','O','R','M','U','L','A',' ','T','O',
	'O',' ','C','O','M','P','L','E','','C','A','N',39,'T',' ','C','O','N',
	'T','I','N','U','','U','N','D','E','F',39,'D',' ','F','U','N','C','T',
	'I','O','','V','E','R','I','F','','L','O','A','','','','','','',
	'','','','','','','','','',255,'',16,'','%','','5','',';',
	'','O','','Z','','j','','r','','','','','','','','','','',
	'','','','','','','','','',0,'',14,'',30,'','$','','','',
	13,'O','K',13,0,' ',' ','E','R','R','O','R',0,' ','I','N',' ',0,13,10,
	'R','E','A','D','Y','.',13,10,0,13,10,'B','R','E','A','K',0,'','','',
	'','','','',1,1,'','','','!','','J','',10,'',2,1,'','I','',
	3,1,'','J','',3,1,'',7,'','I','',2,1,'',7,'',24,'i',18,'','',
	'','`',' ',8,'','','1','','2','8','','Z','','_','',34,'','','[',
	'','`','','','','','#','','Z','8','',34,'','Z','',3,'','[','8',
	'','X','',34,'','X','',8,'','Y','',4,'','Z','','X','','','',
	'','Z','','X','','[','','Y','','','','`',10,'i','>','','5','',
	34,'','',34,'','.','`','','4','','(','',4,'','3','',34,'H','',
	9,'','H','','W','',16,'',' ','&','','','','h','','a','','0','',
	'h','','h','','4','',6,'',5,'','3','',1,'`','',16,'l',0,3,'',10,
	'','','&','','',34,'',39,'','','#',' ','',255,'',0,'',19,' ',
	'','',' ','E','','',0,'',34,'H',')','',' ','G','','','h',16,'',
	' ','z','','','i','','',' ',30,'','',':','','',3,' ','','','',
	'v','','',' ',30,'','','',' ','',255,'l',2,3,' ','`','','','z',
	'','{',' ','s',0,'','','','',255,'',':','',6,' ','y','','L','',
	'',' ','k','',' ','y','','',11,' ',19,'','','D','',1,'','_','',
	'#','','-','',34,'','`','','%','','_','','','_',24,'e','-','',
	'-','','$','','.','i',255,'','.','','`','','8','','_','','-','',
	'',3,'','','%',24,'e',34,'',3,'','#',24,'',34,'','$','','','',
	'','#','','%','','','',' ','Y','',' ','3','','',0,2,'','',24,
	'','-','','Z','e',11,'','X','','.','','[','',1,'','','Y',' ','',
	'','',20,'',21,'','',1,'',255,1,'','1','','2','','-','','.',
	'',11,'','','',1,'','_','',16,'',' ','Y','',' ','3','','L','',
	'','','+','',',','',34,'','#',24,'',1,'',34,'',29,'',4,'','',
	34,'','','','','e',34,'','',0,'',34,'','#','i',0,'','',34,'',
	34,'','#','','','`','',0,' ',18,'','',13,'',13,'',0,2,'','',
	'Y','','','',23,'L','7','','L','','','l',4,3,'','z','',4,'',15,
	'',0,2,16,7,'',255,'','>','','','','',' ','','7','',8,'',34,
	'','V','$',15,'p','-','','?','',4,'','','','%','','0','',4,'',
	'<','',29,'','q','',0,'',11,'','','z','','','','',0,2,'8','',
	'','','','','','','','0',5,11,'','q','','','','',1,'','',
	1,'','6','8','',':','',4,'','I','',2,'',15,'8','','U','','','',
	8,'',0,2,'','','',8,'','','','','',1,'','','','','z','',
	11,'','','','',16,'','','','','','','',0,2,16,'','','',1,
	'','{','',255,'','z','`','','+','',',','',1,'','_','','`','',
	'_','',31,'','','',21,'','_','',24,'',3,'','',9,'',20,'','',
	'_','',12,'',10,'','','_','','','','_','','',24,'`','','','',
	0,'','','+','','','+','','+',24,'i',2,'','-','',',','i',0,'','.',
	' ','','','',0,'','-',' ','',255,'','7','','8','','3','','4',
	'','-','','.','','/','','0','','1','','2',' ',29,'','',25,'',
	22,'h','','h','','','','H','','H','',0,'','>','',16,'`',24,'',
	'+','i',255,'','z','',',','i',255,'','{','`','',6,'',4,'','','',
	'',' ','k','',' ',19,'',' ','y',0,'',12,'','','','',' ','s',0,
	' ','k','','','','h','h','',20,5,21,'',6,'',255,'',20,'',21,'',
	1,'',15,'','_','','C',' ',',','',' ','','','','','_','','','',
	'_','',21,'',4,'',20,'',2,'',',','','I',' ','','','',' ','',
	'I',')','',' ','G','','',34,'',6,'',15,'I',255,'',15,'','',17,
	'','_','',16,'','','_','','','','_','','_','','`','','','L',
	'','','l',6,3,16,'','',255,'','','$',15,'0','','8','','','',
	'','I','',255,'','',8,'','','','',16,'','0','','','','','',
	'0','',' ','G','','','','','','',16,' ','','',' ','','','',
	5,'','i',15,'','','h','h','',9,' ','','',' ',6,'',24,'','e','z',
	'H','','{','i',0,'H','',':','H','','9','H','','',' ',255,'',' ',
	'','',' ','','','','f',9,'','%','b','','b','','','','','',
	34,'','#','L','C','','','','','',' ','','',' ','y',0,'','','',
	6,' ','s',0,' ','','',' ','+','',' ','8','','','J','H','','I','H',
	'','','H',' ',',','','','z','','{','',2,'','',4,'','=','','>',
	'',0,'','z','','C','',2,'','z',24,'',3,'L','K','','','','z','',
	'9','','','z','',':','','e','z','','z','',2,'','{','l',8,3,' ',
	's',0,' ','','','L','','','','<','','','',17,'','#','',23,10,
	'','',13,'','H','',12,'','H','L','s',0,'L','','','',':','','',
	'L',8,'','','K','','',' ','s',0,'','',' ',255,'','L','','','8',
	'','+','',1,'',',','',1,'','','A','','B','`',' ','',255,'',1,
	24,'','<','','z','','{','',':','','',12,'','=','','>','','9',
	'',':','',';','','<','h','h','','','','','',3,'L','i','','L',
	'','','',23,'',26,'','>','',3,'L','7','','','=','','z','','{',
	'',';','','<','','9','',':','`',8,'',0,' ','',255,'(','',3,'L',
	'Y','',' ','`','','L','','','',3,' ','','','','{','H','','z',
	'H','',':','H','','9','H','','','H',' ','y',0,' ','','','L','',
	'',' ','k','',' ',9,'','8','','9','',20,'',':','',21,'',11,'',
	'8','e','z','','{','',7,'','',4,'','+','',',',' ',23,'','',30,
	'','_','',1,'','z','','`','',0,'','{','`','','','',255,'','J',
	' ','','','','','','',11,'',12,',','',17,'L','7','','L',8,'',
	'h','h','','9','h','',':','h','','z','h','','{',' ',6,'','',24,'e',
	'z','','z','',2,'','{','`','',':',',','',0,'',7,'',0,'',8,'',
	8,'',7,'',7,'',8,'','z','','','',8,'','','','',34,'','','',
	'',' ','','',' ','y',0,'','','',5,'','',' ',255,'','','a','',
	5,' ',9,'','','',' ','y',0,'',3,'L','','','L','','',' ','','',
	'H','','','',4,'','','','','','e','',4,'h','L','','',' ','s',
	0,' ','k','','',',','','','h','`','',0,'',20,'',21,'','','',
	'/','',7,'',21,'',34,'',25,'','','',20,10,'&',34,10,'&',34,'e',
	20,'',20,'',34,'e',21,'',21,6,20,'&',21,'',20,'e',7,'',20,'',2,'',
	21,' ','s',0,'L','q','',' ','','','','I','','J','','',' ',255,'',
	'',14,'H','',13,'H',' ','','','h','*',' ','','','',24,'h',16,18,
	' ',27,'',' ','','','',0,'','d','','I','','','e','','I','`','L',
	'','','h','','J','','','','L',' ','','','',6,'','=','',0,'',
	'a','','f','','q',' ',29,'',' ','','','','q','','q',' ',29,'',
	' ',12,'','','',5,'','',' ','','','','q','','',6,'','',' ',
	'','',' ','','','','d','','c','','e','L','',255,'',34,' ','',
	0,'',3,'L','H','','','/','L','~','','',2,'','d','','4','',23,'',
	7,'','','d','','3','',14,'','e','','.','',8,'',13,'','d','',
	'-','',7,'','d','','e','L','h','','',0,'','d',' ','u','','','P',
	'','Q','','o','','p',' ','z','','','a','',0,'','P','','Q',' ',
	'','','',0,'','P','','I','','','P','','I','','','P','','I',
	'`',' ','','','L','','',' ','','','',5,'',',',' ',255,'',8,'',
	19,' ',24,'','(','L','','',' ','!','',' ','y',0,'','5','','C','',
	'','','P','','',24,'','K','',',','','7','',';','','^',' ','',
	'','$',13,'0','',' ','','',' ','','',' ','!','',' ',';','','',
	'','',0,'',0,2,'',255,'',1,'',19,'',16,'',13,' ','G','','$',19,
	16,5,'',10,' ','G','','I',255,'`','8',' ','',255,'','8','',10,'',
	'','I',255,'i',1,'',22,8,'8',' ','',255,'',9,' ','','','',')','',
	'Y','(','',6,'','',9,'',5,'','','','',6,' ','s',0,'L','','',
	' ',';','','','',' ','','',' ','','','','',0,'','','','',
	'',34,' ','G','','','',13,'','',' ','','','L','(','','',19,'',
	3,'',' ',',','',29,',','','?',' ',12,'',')',255,'`','',17,'',17,
	'0',4,'',255,'',4,'','?','','@','','9','',':','L',8,'','',19,'',
	5,'',24,'L','7','','',12,'','',' ',30,'','','=','','>','','z',
	'','{','`',' ','','','','#','',16,' ','s',0,' ','','','',',',' ',
	255,'','',19,' ',30,'','',1,'',2,'',0,'',1,2,'','@',' ',15,'',
	'',19,'',19,'`',' ','','','',',',' ',255,'','',19,' ',30,'',' ',
	'','','',19,' ','',255,'',0,'',19,'`','',34,'',11,' ','','',
	'',';',' ',255,'',' ','!','',' ','','','',',','',255,1,' ','',
	'','',19,'',13,' ','',255,')',2,'',6,' ','','','L','','','',
	0,2,'',30,'',19,'','',' ',6,'','L','','','',19,'',6,' ','E','',
	' ',';','','L','`','','','A','','B','','',',','',0,'',17,'','C',
	'','D',' ','','','','I','','J','','z','','{','','K','','L','',
	'C','','D','','z','','{',' ','y',0,'',' ','$',17,'P',12,' ','$','',
	'',0,2,'',255,'',1,'',12,'0','u','',19,'',3,' ','E','',' ','',
	'','','z','','{',' ','s',0,'$',13,16,'1','$',17,'P',9,'','','z','',
	0,'',7,'',12,'',7,'',34,'',7,'',':','',7,'',',',24,'',8,'','z',
	'','{','i',0,'',1,'',' ','','',' ','','',' ','','','L','','',
	' ','','','',14,' ','','',' ','y',0,'',7,'',',','',3,'L','M','',
	'','z','','{','','C','','D','','K','','L','','z','','{',' ','y',
	0,'','-',' ','','','L',21,'',' ',6,'','','','',18,'',13,'','',
	'z','','l','','','z','','?','','','z','','','@',' ','','',' ',
	'y',0,'','','','','','L','Q','','','C','','D','',17,16,3,'L',
	39,'','',0,'','C','',11,'',19,'',7,'','','','','L',30,'','`',
	'?','E','X','T','R','A',' ','I','G','N','O','R','E','D',13,0,'?','R','E',
	'D','O',' ','F','R','O','M',' ','S','T','A','R','T',13,0,'',4,'',0,'',
	3,' ','','','','I','','J',' ','','','',5,'',10,'L','7','','',
	'',24,'i',4,'H','i',6,'','$','h','',1,' ','','','','',9,1,'','f',
	'','I','','J',' ','g','',' ','','','',1,' ',']','','','8','',
	9,1,'',23,'',15,1,'','9','',16,1,'',':','',18,1,'','z','',17,1,
	'','{','L','','','','i',17,'','',' ','y',0,'',',','','',' ','s',
	0,' ','$','',' ','','',24,'$','8','$',13,'0',3,'',3,'`','','','',
	22,'L','7','','','z','',2,'','{','','z','',0,'$','H','','H','',
	1,' ','','',' ','','','',0,'','M',' ','y',0,'8','','','',23,'',
	3,'',19,'',1,'*','I',1,'E','M','','M','','a','','M',' ','s',0,'L',
	'','','','M','',',','','{','i',7,'','w','e',13,'',3,'L','=','',
	'i',255,'',34,10,'e',34,'','h','','','','','g',' ','','','H',' ',
	' ','','h','','K',16,23,'','','V','','_','F',13,'','*','','z','',
	2,'','{','','z','',27,'','M','','','','','','','H','','','',
	'','','H','','','','H',' ','3','','','M','L','','','L',8,'',
	'','f','','','','','h','',34,'',34,'h','','#','','H',' ',27,'',
	'','e','H','','d','H','','c','H','','b','H','','a','H','l',34,0,'',
	255,'h','','#','','d','',3,' ','','','','K','h','J','',18,'h','',
	'i','h','','j','h','','k','h','','l','h','','m','h','','n','E','f',
	'','o','','a','`','l',10,3,'',0,'',13,' ','s',0,'',3,'L','','',
	' ',19,'','',3,'L','(','','',255,'',15,'','','','',' ','','',
	'L','s',0,'','I',15,'','','','.','','','','','','X','','','',
	'','',34,'',15,'','z','','{','i',0,'',1,'',' ','','','L','',
	'','','','',19,'',24,'',';',' ','','','','e','I',255,'','',
	'd','I',255,'L','','','','','',3,'L','','','','','',3,'L','',
	'',' ','','',' ','','','',')',',','','(',',','',',','',0,'',
	'z','',3,'L','s',0,'',11,'L','7','','',21,'h','h','L','','','8',
	'','d','',0,'','e','','','',8,'','','','d','','','','e','`',
	' ','','','','d','','e','','E','','F','',13,'','&','',0,'','p',
	' ',20,'','',28,'','T','',24,'','','',20,' ','','','','^','',
	'','q','',6,'',']','','$',' ','h','','L','o','','`','$',14,16,13,
	'',0,'','d','','','','d','','','L','','',' ',20,'','','-','',
	'T','',27,'','I','','%',' ','','','','','','L','O','',' ','',
	255,'','d','','c','','e','',0,'','b','`','','S','',10,'','T','',
	6,' ','',255,'L','<','','','d','','e','L','','',10,'H','',' ','s',
	0,'','','',' ',' ','','',' ','','',' ','','',' ','','','h',
	'','','e','H','','d','H','','H',' ','','','h','','','H','L','',
	'',' ','','','h','','','','','','U','','','','','V',' ','T',
	0,'L','','','',255,',','',0,'',11,' ','','','','d','E',11,'',
	7,'','e','E',11,'',8,' ','','',' ','','','','e','E',11,'%',8,'E',
	11,'','','d','E',11,'%',7,'E',11,'L','','',' ','','','',19,'',
	'n',9,'','%','j','','j','','i','',0,' ','[','','','L','a','','',
	0,'',13,'','M',' ','','','','a','','b','','c','','l','','m',' ',
	'','','','l','','m','','8','','a','',8,'',1,'',4,'','a','',
	255,'','f','',255,'','','','',7,'','f','0',15,24,'',12,'','l',
	'','b','','','',255,'',2,'',1,'','','*','%',18,'',2,'',255,'L',
	'<','',' ','','','',' ','','',' ','y',0,'','','`','',0,' ','y',
	0,'',12,'','E',' ','y',0,' ',19,'','',3,'L',8,'','',0,'',13,'',
	14,' ','s',0,'',5,' ',19,'','',11,'',' ','s',0,'','',' ',19,'',
	'','','','$','',6,'',255,'',13,'',16,'','%','',19,'',16,'',
	'','','','',14,5,'E','','E','',9,'','',' ','s',0,'','F','8',5,
	16,'','(','',3,'L','','','',0,'',16,'','-','','.','','`','',
	'_','','0','',4,'','/','',34,'','E','','_','',8,'','F','','',
	'_','','}','',24,'','_','i',7,'','','','','','','A','',5,'',
	'[','8','','','`','h','H','','*','',5,'',19,'','','`','','E','',
	'F','','T','',11,'','','','','','I','',3,'L',8,'','','S','',
	4,'','T','','','','/','','0','','_','','`','','1','','2','',
	'Z','','[',24,'i',7,'',1,'','','X','','Y',' ','','','','X','',
	'Y','','','/','','0','',0,'','E','','_','','','F','','_','',
	0,'','','_','','','_','','','_','','','_','','','_','','_',
	24,'i',2,'','`','',1,'','','G','','H','`','',11,10,'i',5,'e','_',
	'','`','',1,'','','X','','Y','`','','',0,0,0,' ','','','','d',
	'','e','`',' ','s',0,' ','','',' ','','','','f','0',13,'','a','',
	'','',9,'','','','',' ','[','','','z','L','','','',12,5,14,
	'H','',13,'H','',0,'','H','','F','H','','E','H',' ','','','h','',
	'E','h','','F','h','','','',2,1,'H','',1,1,'H','','d','',2,1,'',
	'e','',1,1,'',' ','y',0,'',',','','','',11,' ','','','h','',13,
	'h','',14,')','','',12,'','/','','0','','_','','`','','2','',
	4,'','1','','9','',0,'','_','','','E','',6,'','F','','_','',
	22,'','','_',24,'e','_','','','','_','e','`','','','',18,',','',
	14,'L','7','','',19,'',12,'','',' ','','','',11,'',4,'','_',
	'','','L','','',' ','','',' ',8,'','',0,'','r','',5,'','E',
	'','_',16,1,'','','','F','','_',16,2,'','','','q','',11,'','',
	'','','_','',11,'',0,'$',12,'P',8,'h',24,'i',1,'','h','i',0,'','',
	'_','','','','_',' ','L','','','q','','r','',34,'',11,'','',
	'e','Y','',']','','Y','','','e','X','',3,'','','R',' ',8,'','',
	'1','','2','',0,'','r','','q','',5,'','','X','','','','Y','',
	'r','','','','Y','8','','1','','_','',2,'','_','','2','','',
	'`','','_','',12,'','b','','','_','',11,'',0,'','q','','r','',
	'h','','','d','h','','e','','_','',14,'',6,'','','','_','',7,
	'L','E','','L','5','','','','r',5,'q',24,'',10,' ','L','','','e',
	'd','','','',34,'e','e','','q','',11,'','','','r','',5,'','E',
	16,1,'','','F',16,2,'','','','(','',0,' ','U','','','e','X','',
	'G','','e','Y','','H','','','G','`','',34,'','_','','(','','',
	'_','',')','',16,'',']','',0,'',0,'',10,'','','*','','','',
	6,'q','&','r','',11,24,'','e','(','','','e',')','','','','',']',
	'','','`','',13,'',3,' ','','',' ','&','','8','','3','','1','',
	'','4','','2','',0,'',13,'','b','','c','','','L','D','','8',' ',
	'',255,'',0,'','','',':','','','','',21,',','',27,'L','7','',
	' ','','',' ','','',' ','','','','','',16,' ','','',' ','',
	'',' ','','','','',' ',255,'','H','','H','H','','G','H','','{',
	'H','','z','H',' ','','','L','O','','','',' ',255,'',9,'','',
	16,' ','','','','N','','O','L','','',' ','','','','O','H','',
	'N','H',' ','','',' ','','','h','','N','h','','O','',2,'','N',
	'','G','','','','N','','','','H','','','G','H','',16,'','',
	'H',' ','','','','{','H','','z','H','','N','','z','','','N','',
	'{','','H','H','','G','H',' ','','','h','','N','h','','O',' ','y',
	0,'',3,'L',8,'','h','','z','h','','{','',0,'h','','N','h','','',
	'N','h','','','N','h','','','N','h','','','N','`',' ','','','',
	0,' ','','','h','h','',255,'',0,'',18,'','d','','e','','P','',
	'Q',' ','','','','b','','c','','a','`','',34,'',7,'',8,'','o',
	'','p','','b','','c','',255,'','','o','',12,'',7,'',4,'',8,'',
	'','',34,'',1,24,'','a','','e','o','','q','','p','',1,'','',
	'r','','p','',4,'',2,'',11,'',' ','u','','','o','','p',' ','',
	'','',22,'',34,'',5,'',25,'L','7','','','a','',0,'','b','',1,
	'','c','',2,'',0,'','d','','e','','p','','',13,'',23,'','',
	'','',22,'`','F',15,'H','I',255,'8','e','3','','4','',1,'','','2',
	'',17,'',4,'','1','',11,'','3','','4','','5','','6','','h','`',
	'',16,'',15,'0','',' ','&','','','','',15,'h','','','','7','',
	'8','','3','','4','',0,'','O','','N','','1','','2','','_','',
	'`','',25,'',0,'',34,'','#','',22,'',5,' ','','','','','',7,
	'','S','','-','','.','',34,'','#','','0','',4,'','/','',5,' ',
	'','','','','','X','','Y','',3,'','S','','X','','Y','','2',
	'',7,'','1','',3,'L',6,'','',34,'','#','',0,'',34,'','','',
	34,8,'','',34,'e','X','','X','','',34,'e','Y','','Y','(',16,'',
	'','0','','','',34,'',0,10,'i',5,'e',34,'',34,'',2,'','#','',
	'#','','Y','',4,'','X','','',' ','','','','','',34,'0','5','',
	'',34,16,'0','','',34,'','+','','',34,'','','',34,'','4','',
	6,'',30,'','3','',26,'','`','',22,'',4,'','_','',16,'','_','',
	'`','',34,'','#','','N','','O','','S','','U','','S',24,'e',34,'',
	34,'',2,'','#','','#','',0,'`','','O',5,'N','','','','U',')',4,
	'J','','','U','','N','e','_','','Z','','`','i',0,'','[','','3',
	'','4','','X','','Y',' ','','','','U','','','X','','N','','',
	'Y','','Y','','','N','L','*','','','e','H','','d','H',' ','','',
	' ','','','h','','o','h','','p','',0,'','o',24,'q','d','',5,'',
	23,'L','7','',' ','u','',' ','z','','','P','','Q',' ','','',' ',
	'','','','o','','p',' ','','',' ','','','L','','','',0,'',
	'o','H','','','o','','','','o','','h','',34,'','#','','',10,
	'H','','',34,'','5','','','','h',24,'e','5','','5','',2,'','6',
	'`',' ','','','','d','','e','',34,'','#',' ','','',8,'',0,'',
	34,'H','','',34,'','','',34,'','h','(','',19,'','4','',15,'',
	'3','',11,'H',24,'e','3','','3','',2,'','4','h','',34,'','#','`',
	'',24,'',12,'',23,'',8,'',22,'',3,'',23,'',0,'`',' ','','','',
	'H','',1,' ','}','','h','',0,'','b','h','h','L','','',' ','a','',
	'','P','','',4,'','P','','','H','','H',' ','}','','','P','',
	'Q',' ','','','h','','h',24,'e',34,'',34,'',2,'','#','',' ','',
	'','L','','',' ','a','',24,'','P','I',255,'L',6,'','',255,'','e',
	' ','y',0,'',')','',6,' ','','',' ','','',' ','a','','','K','',
	'','H',24,'',0,'','P','','','I',255,'','e','','','','e','','',
	' ','','','h','','h','','U','h','h','h','','h','','P','h','','Q',
	'','U','H','','H','',0,'','`',' ','','','L','','',' ','','',
	'',0,'',13,'','`',' ','','','',8,'',0,'',34,'','L','','','L',
	'H','',' ','s',0,' ','','',' ','','','','d','','','','e','L',
	'y',0,' ','','','',3,'L','','','','z','','{','','q','','r','',
	34,'','z',24,'e',34,'','$','','#','','{','',1,'','','%','',0,'',
	'$','H','','','$',' ','y',0,' ','','','h','',0,'','$','','q','',
	'r','','z','','{','`',' ','','',' ','','',' ','','','L','','',
	'','f','0','','','a','','','','',' ','','','','d','','e','',
	20,'',21,'`','',21,'H','',20,'H',' ','','','',0,'',20,'','h','',
	20,'h','',21,'L','','',' ','','','','',0,'',20,'`',' ','','',
	'','I','',0,' ','y',0,'',3,' ','','','','J','',0,'',20,'E','J',
	'%','I','','','`','',17,'','','L','g','',' ','','','','f','I',
	255,'','f','E','n','','o','','a','L','j','',' ','','','','<',' ',
	'','','',3,'L','','','','p','','V','','i','','i','','','',
	'8','','a','','$','',18,'','a','','n','','f','I',255,'i',0,'',0,
	'','V','','a','',4,'',0,'','p','','','0','','','','p','V',1,
	' ','','','$','o',16,'W','','a','','i','',2,'','i','8','I',255,'e',
	'V','','p','',4,0,'',4,'','e','',3,0,'',3,'','d','',2,0,'',2,
	'','c','',1,0,'',1,'','b','',3,' ','G','','',0,'',24,'','b','',
	'J','','c','','b','','d','','c','','e','','d','','p','','e','',
	'p','i',8,'',' ','','','',0,'','a','','f','`','e','V','','p','',
	'e','e','m','','e','','d','e','l','','d','','c','e','k','','c','',
	'b','e','j','','b','L','6','','i',1,6,'p','&','e','&','d','&','c','&',
	'b',16,'','8','','a','','','I',255,'i',1,'','a','',14,'','a','',
	'B','f','b','f','c','f','d','f','e','f','p','`','','f','I',255,'','f',
	'','b','I',255,'','b','','c','I',255,'','c','','d','I',255,'','d',
	'','e','I',255,'','e','','p','I',255,'','p','','p','',14,'','e',
	'',10,'','d','',6,'','c','',2,'','b','`','',15,'L','7','','',
	'%','',4,'','p','',3,'',4,'',2,'',3,'',1,'',2,'','h','',1,'i',
	8,'0','','','','',8,'','','p','',20,22,1,'',2,'',1,'v',1,'v',
	1,'v',2,'v',3,'v',4,'j','','','',24,'`','',0,0,0,0,3,'','^','V','',
	'y','',19,'',11,'d','','v','8','',22,'','8','',';',' ','','5',4,
	'','4','','5',4,'','4','','',0,0,0,'','1','r',23,'',' ','+','',
	'',2,16,3,'L','H','','','a','','','H','','','','a','','','',
	'',' ','g','','','','','',' ',15,'','','','','',' ','P','',
	'','','','',' ','C','','','','','',' ','g','','h',' ','~','',
	'','','','',' ','','','',3,'L','','',' ','','','',0,'','&',
	'',39,'','(','',')','','p',' ','Y','','','e',' ','Y','','','d',
	' ','Y','','','c',' ','Y','','','b',' ','^','','L','','','',3,
	'L','','','J',9,'','','',25,24,'',')','e','m','',')','','(','e',
	'l','','(','',39,'e','k','',39,'','&','e','j','','&','f','&','f',
	39,'f','(','f',')','f','p','','J','','','`','',34,'','#','',4,'',
	34,'','m','','',34,'','l','','',34,'','k','','',34,'','n','E',
	'f','','o','','n',9,'','','j','','',34,'','i','','a','`','','i',
	'',31,24,'e','a','',4,'0',29,24,',',16,20,'i','','','a','',3,'L',
	'','','','o','','f','`','','f','I',255,'0',5,'h','h','L','','',
	'L','~','',' ',12,'','','',16,24,'i',2,'','','',0,'','o',' ','w',
	'','','a','','','`','',' ',0,0,0,' ',12,'','','','','','',0,
	'','o',' ','','','L',18,'',' ','','','','v',' ',27,'','',0,'8',
	'','a','','a',' ','','','','a','','','','','',1,'','j','',
	'b','',16,'','k','','c','',10,'','l','','d','',4,'','m','','e',
	8,'*','',9,'','',')','','2',16,'4','',1,'(','',14,6,'m','&','l',
	'&','k','&','j','','','0','',16,'','','','m','','e','','m','',
	'l','','d','','l','','k','','c','','k','','j','','b','','j','',
	'L','O','','','@','','',10,10,10,10,10,10,'','p','(','L','','',
	'',20,'L','7','','','&','','b','',39,'','c','','(','','d','',
	')','','e','L','','','',34,'','#','',4,'',34,'','e','','',34,
	'','d','','',34,'','c','','',34,'','f',9,'','','b','','',34,
	'','a','','p','`','','\\',',','','W','',0,'',4,'','I','','J',' ',
	27,'','',34,'','#','',4,'','e','',34,'','','d','',34,'','',
	'c','',34,'','','f',9,'','%','b','',34,'','','a','',34,'','p',
	'`','','n','','f','',5,'','h','','`','','','','','p','`',' ',
	27,'','',6,'','`','','h','','','','','p','`','','a','','',6,
	'p','','',' ','o','','','','L','8','','','a','',9,'','f','*',
	'',255,'',2,'',1,'`',' ','+','','','b','',0,'','c','','','',
	'b','I',255,'*','',0,'','e','','d','','a','','p','','f','L','',
	'','F','f','`','','$','','%','',0,'','$','','','','','','$',
	'E','f','0','','','a','','!','','$',9,'','','b','',25,'','','$',
	'','c','',18,'','','$','','d','',11,'','','','','p','','$',
	'','e','','(','','f','',2,'I',255,'L','1','','','a','','J','8',
	'','','$','f',16,9,'','',255,'','h',' ','M','','','','a','','',
	16,6,' ','','','','h','`','','','f',')','','F','b',5,'b','','b',
	' ','','','','h','`','','a','','','',' ',' ','','','','p','',
	'f','','f','I','','*','','','','a','','e','',7,'L','','','',
	'b','','c','','d','','e','','`','',0,'',10,'',']','',16,'','',
	15,'','-','',4,'','g','',4,'','+','',5,' ','s',0,'','[','','.',
	'','.','','E','','0',' ','s',0,'',23,'','','',14,'','-','',10,
	'','','',8,'','+','',4,'',7,'f','`',' ','s',0,'','\\','$','`',16,
	14,'',0,'8','','^','L','I','','f','_','$','_','P','','','^','8','',
	']','','^','',18,16,9,' ','','','','^','','','',7,' ','','',
	'','^','','','','g','0',1,'`','L','','','H','$','_',16,2,'',']',
	' ','','','h','8','','0',' ','~','','L',10,'','H',' ',12,'','h',
	' ','<','','','n','E','f','','o','','a','L','j','','','^','',10,
	'',9,'','d','$','`','0',17,'L','~','',10,10,24,'e','^',10,24,'',0,
	'q','z','8','','0','','^','L','0','','','>','',31,'','','n','k',
	39,'','','n','k','(',0,'','q','','',' ','','','',':','','9','',
	'b','','c','','','8',' ','I','',' ','','','L',30,'','',1,'',' ',
	'$','f',16,2,'','-','',255,0,'','f','','q','','','0','','a','',
	3,'L',4,'','',0,'','','',2,'',9,'','','','',' ','(','','',
	'','',']','','','','',' ','[','','',30,16,18,'','','','',' ',
	'[','','',2,16,14,' ','','','',']','','',' ','','','',']','',
	'',' ','I','',' ','','','',1,'',']',24,'i',10,'0',9,'',11,'',6,
	'i',255,'','',2,'8','',2,'','^','',']','','',2,16,19,'','q','',
	'.','','',255,0,'','',6,'','0','','',255,0,'','q','',0,'','',
	'','e',24,'y',25,'','','e','','d','y',24,'','','d','','c','y',23,
	'','','c','','b','y',22,'','','b','','',4,16,'','0',2,'0','',
	'','',4,'I',255,'i',10,'i','/','','','','','','G','','q','','',
	')','','',255,0,'',']','',6,'','.','','',255,0,'','q','','G',
	'','I',255,')','','','','$','',4,'','<','','','','q','',255,
	0,'','','0','','','','.','',1,'','','+','','^','','.',16,8,'',
	0,'8','','^','','','-','',1,1,'','E','',0,1,'','','/','8','',
	'',10,'','','i',':','',3,1,'','',2,1,'',0,'',4,1,'',8,'',255,
	0,'',0,'',0,1,'',0,'',1,'`','',0,0,0,0,'',10,31,0,0,'','','',
	255,'','','',0,1,'','',255,255,'','',0,0,3,'',255,255,255,'',
	0,0,0,10,255,255,255,255,255,'',10,'',0,3,'K','',255,255,'s','`',0,
	0,14,16,255,255,'','',0,0,0,'<','','','','','','','','','',
	'','','','','','','','','','','','','','','','','','',
	'','','','',' ',12,'','',17,'','',' ','','','','p','','i',
	'',3,'L','','','','N','',0,' ','','','','n',16,15,' ','','',
	'','N','',0,' ','[','','',3,'','',7,' ','','','','H',' ','',
	'','','N','',0,' ','(','',' ','','','h','J','',10,'','a','',6,
	'','f','I',255,'','f','`','','8','',';',')',7,'q','4','X','>','V',
	't',22,'~','',27,'w','/','','','','z',29,'',28,'*','|','c','Y','X',
	10,'~','u','','','','','1','r',24,16,'',0,0,0,0,'','','','',' ',
	'(','','','p','i','P','',3,' ','#','','L',0,'',0
};

BYTE ORIGINAL64C[4097] = 
{
	'<','f','n','n','`','b','<',0,24,'<','f','~','f','f','f',0,'|','f','f',
	'|','f','f','|',0,'<','f','`','`','`','f','<',0,'x','l','f','f','f','l',
	'x',0,'~','`','`','x','`','`','~',0,'~','`','`','x','`','`','`',0,'<',
	'f','`','n','f','f','<',0,'f','f','f','~','f','f','f',0,'<',24,24,24,24,
	24,'<',0,30,12,12,12,12,'l','8',0,'f','l','x','p','x','l','f',0,'`','`',
	'`','`','`','`','~',0,'c','w','','k','c','c','c',0,'f','v','~','~','n',
	'f','f',0,'<','f','f','f','f','f','<',0,'|','f','f','|','`','`','`',0,
	'<','f','f','f','f','<',14,0,'|','f','f','|','x','l','f',0,'<','f','`',
	'<',6,'f','<',0,'~',24,24,24,24,24,24,0,'f','f','f','f','f','f','<',0,
	'f','f','f','f','f','<',24,0,'c','c','c','k','','w','c',0,'f','f','<',
	24,'<','f','f',0,'f','f','f','<',24,24,24,0,'~',6,12,24,'0','`','~',0,
	'<','0','0','0','0','0','<',0,12,18,'0','|','0','b','',0,'<',12,12,12,
	12,12,'<',0,0,24,'<','~',24,24,24,24,0,16,'0','','','0',16,0,0,0,0,0,
	0,0,0,0,24,24,24,24,0,0,24,0,'f','f','f',0,0,0,0,0,'f','f',255,'f',255,
	'f','f',0,24,'>','`','<',6,'|',24,0,'b','f',12,24,'0','f','F',0,'<','f',
	'<','8','g','f','?',0,6,12,24,0,0,0,0,0,12,24,'0','0','0',24,12,0,'0',
	24,12,12,12,24,'0',0,0,'f','<',255,'<','f',0,0,0,24,24,'~',24,24,0,0,0,
	0,0,0,0,24,24,'0',0,0,0,'~',0,0,0,0,0,0,0,0,0,24,24,0,0,3,6,12,24,'0',
	'`',0,'<','f','n','v','f','f','<',0,24,24,'8',24,24,24,'~',0,'<','f',6,
	12,'0','`','~',0,'<','f',6,28,6,'f','<',0,6,14,30,'f','',6,6,0,'~','`',
	'|',6,6,'f','<',0,'<','f','`','|','f','f','<',0,'~','f',12,24,24,24,24,
	0,'<','f','f','<','f','f','<',0,'<','f','f','>',6,'f','<',0,0,0,24,0,0,
	24,0,0,0,0,24,0,0,24,24,'0',14,24,'0','`','0',24,14,0,0,0,'~',0,'~',0,
	0,0,'p',24,12,6,12,24,'p',0,'<','f',6,12,24,0,24,0,0,0,0,255,255,0,0,0,
	8,28,'>','','',28,'>',0,24,24,24,24,24,24,24,24,0,0,0,255,255,0,0,0,
	0,0,255,255,0,0,0,0,0,255,255,0,0,0,0,0,0,0,0,0,255,255,0,0,'0','0','0',
	'0','0','0','0','0',12,12,12,12,12,12,12,12,0,0,0,'','','8',24,24,24,
	24,28,15,7,0,0,0,24,24,'8','','',0,0,0,'','','','','','',255,255,
	'','','p','8',28,14,7,3,3,7,14,28,'8','p','','',255,255,'','','',
	'','','',255,255,3,3,3,3,3,3,0,'<','~','~','~','~','<',0,0,0,0,0,0,
	255,255,0,'6','','','','>',28,8,0,'`','`','`','`','`','`','`','`',0,
	0,0,7,15,28,24,24,'','','~','<','<','~','','',0,'<','~','f','f','~',
	'<',0,24,24,'f','f',24,24,'<',0,6,6,6,6,6,6,6,6,8,28,'>','','>',28,8,
	0,24,24,24,255,255,24,24,24,'','','0','0','','','0','0',24,24,24,24,
	24,24,24,24,0,0,3,'>','v','6','6',0,255,'','?',31,15,7,3,1,0,0,0,0,0,
	0,0,0,'','','','','','','','',0,0,0,0,255,255,255,255,255,0,0,
	0,0,0,0,0,0,0,0,0,0,0,0,255,'','','','','','','','','','','3',
	'3','','','3','3',3,3,3,3,3,3,3,3,0,0,0,0,'','','3','3',255,'','',
	'','','','','',3,3,3,3,3,3,3,3,24,24,24,31,31,24,24,24,0,0,0,0,15,
	15,15,15,24,24,24,31,31,0,0,0,0,0,0,'','',24,24,24,0,0,0,0,0,0,255,255,
	0,0,0,31,31,24,24,24,24,24,24,255,255,0,0,0,0,0,0,255,255,24,24,24,24,
	24,24,'','',24,24,24,'','','','','','','','','','','','',
	'','','','',7,7,7,7,7,7,7,7,255,255,0,0,0,0,0,0,255,255,255,0,0,0,
	0,0,0,0,0,0,0,255,255,255,3,3,3,3,3,3,255,255,0,0,0,0,'','','','',
	15,15,15,15,0,0,0,0,24,24,24,'','',0,0,0,'','','','',0,0,0,0,'',
	'','','',15,15,15,15,'','','','','','','',255,'','','','',
	'','','',255,'','','','','','','',255,'','','','','','',
	'',255,'','','','','','','',255,'','','','','','','',255,
	'','','','','','','',255,'','','','','','','',255,'','',
	'','','','','',255,'','','','','','','',255,'','','','',
	'','','',255,'','','','','','','',255,'','','','','','',
	'',255,'','','','','','','',255,'','','','','','','',255,
	'','','','','','','',255,'','','','','','','',255,'','',
	'','','','','',255,'','','','','','','',255,'','','','',
	'','','',255,'','','','','','','',255,'','','','','','',
	'',255,'','','','','','','',255,'','','','','','','',255,
	'','','','','','','',255,'','','','','','','',255,'','',
	'','','','','',255,'','','','','','','',255,'','','','',
	'','',3,255,'','','','','','','',255,255,'','','','','',
	'','',255,'','','','','','',255,255,255,255,255,255,255,255,255,
	'','','','',255,255,'',255,'','','',255,255,255,255,255,'','',
	0,'',0,'','',255,'','','','','','','',255,'','','','','',
	'','',255,'','','','','','','',255,'','','',255,255,255,255,
	255,'','','','','','','',255,'','','','','','','',255,255,
	'','',0,'','',255,255,255,'','','','','',255,255,255,255,255,
	255,255,'','','',255,255,255,'',255,255,255,255,255,255,255,255,255,
	'','',255,255,'','','','','','',255,'','','','','','','',
	255,'','','','','','','',255,'','','','','','','',255,'',
	'','','','','','',255,'','','','','','','',255,'','','',
	'','','','',255,'','','','','','','',255,'','','','','',
	'','',255,'','','','','','','',255,'','','','','','','',
	255,255,255,'',255,255,'',255,255,255,255,'',255,255,'','','','',
	'','','','','','',255,255,255,'',255,'',255,255,255,'','','',
	'','','','',255,'','','','','',255,'',255,255,255,255,0,0,255,
	255,255,'','','','','','','',255,'','','','','','','','',
	255,255,255,0,0,255,255,255,255,255,0,0,255,255,255,255,255,0,0,255,255,
	255,255,255,255,255,255,255,0,0,255,255,'','','','','','','','',
	'','','','','','','','',255,255,255,31,15,'','','','','',
	'','','',255,255,255,'','','',15,31,255,255,255,'?','?','?','?',
	'?','?',0,0,'?',31,'','','','','','','','','','','','',31,
	'?',0,0,'?','?','?','?','?','?',0,0,'','','','','','',255,'','',
	'','','','',255,255,255,255,255,255,0,0,255,'','','','','','',
	'',255,'','','','','','','','',255,255,255,'','','','','',
	'<',24,'','','','',24,'<',255,'','','','','','',255,'','',
	'','','','','',255,'','','','','','','','','','','','',
	'','','',255,'','','',0,0,'','','','?','?','','','?','?','',
	'','','','','','','','','',255,255,'','','','','',255,0,
	'','','','','','','',255,255,255,255,255,255,255,255,15,15,15,15,
	15,15,15,15,255,255,255,255,0,0,0,0,0,255,255,255,255,255,255,255,255,
	255,255,255,255,255,255,0,'?','?','?','?','?','?','?','?','3','3','',
	'','3','3','','','','','','','','','','',255,255,255,255,'3',
	'3','','',0,1,3,7,15,31,'?','','','','','','','','','','',
	'','','','','','','',255,255,255,255,'','','','','','','',
	'','',255,255,255,255,255,255,7,7,'','','',255,255,255,255,255,255,
	0,0,255,255,255,'','','','','','','','',0,0,255,255,255,255,255,
	255,0,0,'','','','','','',7,7,'','','','?','?','?','?','?','?',
	'?','?',31,31,31,31,31,31,31,31,'','','','','','','','',0,0,255,
	255,255,255,255,255,0,0,0,255,255,255,255,255,255,255,255,255,255,0,0,
	0,'','','','','','',0,0,255,255,255,255,15,15,15,15,'','','',
	'',255,255,255,255,'','','',7,7,255,255,255,15,15,15,15,255,255,255,
	255,15,15,15,15,'','','','','<','f','n','n','`','b','<',0,0,0,'<',
	6,'>','f','>',0,0,'`','`','|','f','f','|',0,0,0,'<','`','`','`','<',0,
	0,6,6,'>','f','f','>',0,0,0,'<','f','~','`','<',0,0,14,24,'>',24,24,24,
	0,0,0,'>','f','f','>',6,'|',0,'`','`','|','f','f','f',0,0,24,0,'8',24,
	24,'<',0,0,6,0,6,6,6,6,'<',0,'`','`','l','x','l','f',0,0,'8',24,24,24,
	24,'<',0,0,0,'f','','','k','c',0,0,0,'|','f','f','f','f',0,0,0,'<','f',
	'f','f','<',0,0,0,'|','f','f','|','`','`',0,0,'>','f','f','>',6,6,0,0,
	'|','f','`','`','`',0,0,0,'>','`','<',6,'|',0,0,24,'~',24,24,24,14,0,0,
	0,'f','f','f','f','>',0,0,0,'f','f','f','<',24,0,0,0,'c','k','','>','6',
	0,0,0,'f','<',24,'<','f',0,0,0,'f','f','f','>',12,'x',0,0,'~',12,24,'0',
	'~',0,'<','0','0','0','0','0','<',0,12,18,'0','|','0','b','',0,'<',12,
	12,12,12,12,'<',0,0,24,'<','~',24,24,24,24,0,16,'0','','','0',16,0,0,
	0,0,0,0,0,0,0,24,24,24,24,0,0,24,0,'f','f','f',0,0,0,0,0,'f','f',255,'f',
	255,'f','f',0,24,'>','`','<',6,'|',24,0,'b','f',12,24,'0','f','F',0,'<',
	'f','<','8','g','f','?',0,6,12,24,0,0,0,0,0,12,24,'0','0','0',24,12,0,
	'0',24,12,12,12,24,'0',0,0,'f','<',255,'<','f',0,0,0,24,24,'~',24,24,0,
	0,0,0,0,0,0,24,24,'0',0,0,0,'~',0,0,0,0,0,0,0,0,0,24,24,0,0,3,6,12,24,
	'0','`',0,'<','f','n','v','f','f','<',0,24,24,'8',24,24,24,'~',0,'<','f',
	6,12,'0','`','~',0,'<','f',6,28,6,'f','<',0,6,14,30,'f','',6,6,0,'~',
	'`','|',6,6,'f','<',0,'<','f','`','|','f','f','<',0,'~','f',12,24,24,24,
	24,0,'<','f','f','<','f','f','<',0,'<','f','f','>',6,'f','<',0,0,0,24,
	0,0,24,0,0,0,0,24,0,0,24,24,'0',14,24,'0','`','0',24,14,0,0,0,'~',0,'~',
	0,0,0,'p',24,12,6,12,24,'p',0,'<','f',6,12,24,0,24,0,0,0,0,255,255,0,0,
	0,24,'<','f','~','f','f','f',0,'|','f','f','|','f','f','|',0,'<','f','`',
	'`','`','f','<',0,'x','l','f','f','f','l','x',0,'~','`','`','x','`','`',
	'~',0,'~','`','`','x','`','`','`',0,'<','f','`','n','f','f','<',0,'f',
	'f','f','~','f','f','f',0,'<',24,24,24,24,24,'<',0,30,12,12,12,12,'l',
	'8',0,'f','l','x','p','x','l','f',0,'`','`','`','`','`','`','~',0,'c',
	'w','','k','c','c','c',0,'f','v','~','~','n','f','f',0,'<','f','f','f',
	'f','f','<',0,'|','f','f','|','`','`','`',0,'<','f','f','f','f','<',14,
	0,'|','f','f','|','x','l','f',0,'<','f','`','<',6,'f','<',0,'~',24,24,
	24,24,24,24,0,'f','f','f','f','f','f','<',0,'f','f','f','f','f','<',24,
	0,'c','c','c','k','','w','c',0,'f','f','<',24,'<','f','f',0,'f','f','f',
	'<',24,24,24,0,'~',6,12,24,'0','`','~',0,24,24,24,255,255,24,24,24,'',
	'','0','0','','','0','0',24,24,24,24,24,24,24,24,'3','3','','','3',
	'3','','','3','','','f','3','','','f',0,0,0,0,0,0,0,0,'','','',
	'','','','','',0,0,0,0,255,255,255,255,255,0,0,0,0,0,0,0,0,0,0,0,
	0,0,0,255,'','','','','','','','','','','3','3','','','3',
	'3',3,3,3,3,3,3,3,3,0,0,0,0,'','','3','3','','','3','f','','','3',
	'f',3,3,3,3,3,3,3,3,24,24,24,31,31,24,24,24,0,0,0,0,15,15,15,15,24,24,
	24,31,31,0,0,0,0,0,0,'','',24,24,24,0,0,0,0,0,0,255,255,0,0,0,31,31,
	24,24,24,24,24,24,255,255,0,0,0,0,0,0,255,255,24,24,24,24,24,24,'','',
	24,24,24,'','','','','','','','','','','','','','','','',
	7,7,7,7,7,7,7,7,255,255,0,0,0,0,0,0,255,255,255,0,0,0,0,0,0,0,0,0,0,255,
	255,255,1,3,6,'l','x','p','`',0,0,0,0,0,'','','','',15,15,15,15,0,
	0,0,0,24,24,24,'','',0,0,0,'','','','',0,0,0,0,'','','','',15,
	15,15,15,'','','','','','','',255,255,255,'','','','','',255,
	255,'','','','','','',255,255,255,'','','','','',255,255,'',
	'','','','','',255,255,255,'','','','','',255,255,'','','',
	'','','',255,255,255,'','','','','','',255,'','','','','',
	'',255,255,'',255,'','','','',255,255,'',255,'','','','','',
	255,'','','','','','',255,255,'','','','','','',255,255,255,
	'','','','','',255,255,255,'','','','','',255,255,255,'','',
	'','','',255,255,255,'','','','','','',255,255,'','','','',
	'','',255,255,'','','','','',255,255,255,'','','','','',255,
	255,'','','','','','',255,255,255,'','','','','',255,255,255,
	'','','','','',255,255,255,'','','','','',255,255,255,'','',
	'','','',255,255,255,'','','','','','',255,255,'','','','',
	'',255,'','','','','','','',255,'','','','','','',3,255,
	'','','','','','','',255,255,'','','','','','','',255,'',
	'','','','','',255,255,255,255,255,255,255,255,255,'','','','',
	255,255,'',255,'','','',255,255,255,255,255,'','',0,'',0,'','',
	255,'','','','','','','',255,'','','','','','','',255,'',
	'','','','','','',255,'','','',255,255,255,255,255,'','','',
	'','','','',255,'','','','','','','',255,255,'','',0,'',
	'',255,255,255,'','','','','',255,255,255,255,255,255,255,'','',
	'',255,255,255,'',255,255,255,255,255,255,255,255,255,'','',255,255,
	'','','','','','',255,'','','','','','','',255,'','','',
	'','','','',255,'','','','','','','',255,'','','','','',
	'','',255,'','','','','','','',255,'','','','','','','',
	255,'','','','','','','',255,'','','','','','','',255,'',
	'','','','','','',255,'','','','','','','',255,255,255,'',
	255,255,'',255,255,255,255,'',255,255,'','','','','','','','',
	'','',255,255,255,'',255,'',255,255,255,'','','','','','','',
	255,'','','','','',255,'',255,255,255,255,0,0,255,255,255,'','',
	'','','','','',255,'','','','','','','',255,'','','','',
	'','','',255,'','','','','','','',255,'','','','','','',
	'',255,'','','','','','','',255,'','','','','','','',255,
	'','','','','','','',255,'','','','','','','',255,'','',
	'','','','','',255,'','','','','','','',255,'','','','',
	'','','',255,'','','','','','','',255,'','','','','','',
	'',255,'','','','','','','',255,'','','','','','','',255,
	'','','','','','','',255,'','','','','','','',255,'','',
	'','','','','',255,'','','','','','','',255,'','','','',
	'','','',255,'','','','','','','',255,'','','','','','',
	'',255,'','','','','','','',255,'','','','','','','',255,
	'','','','','','','',255,'','','',0,0,'','','','?','?','',
	'','?','?','','','','','','','','','','','','','3','3','',
	'','3','3','','f','3','','','f','3','',255,255,255,255,255,255,255,
	255,15,15,15,15,15,15,15,15,255,255,255,255,0,0,0,0,0,255,255,255,255,
	255,255,255,255,255,255,255,255,255,255,0,'?','?','?','?','?','?','?',
	'?','3','3','','','3','3','','','','','','','','','','',255,
	255,255,255,'3','3','','','3','f','','','3','f','','','','','',
	'','','','','','','','','','','','','',255,255,255,255,'',
	'','','','','','','','',255,255,255,255,255,255,7,7,'','','',
	255,255,255,255,255,255,0,0,255,255,255,'','','','','','','','',
	0,0,255,255,255,255,255,255,0,0,'','','','','','',7,7,'','','',
	'?','?','?','?','?','?','?','?',31,31,31,31,31,31,31,31,'','','','',
	'','','','',0,0,255,255,255,255,255,255,0,0,0,255,255,255,255,255,
	255,255,255,255,255,0,0,0,'','','','','','','',255,255,255,255,
	255,15,15,15,15,'','','','',255,255,255,255,'','','',7,7,255,255,
	255,15,15,15,15,255,255,255,255,15,15,15,15,'','','','',0
};

BYTE ORIGINAL64K[8193] = 
{
	'','V',' ',15,'','','a','','','',3,' ','','',' ','','','',7,
	24,'i','','','','8','',1,'H','',5,'','i','','a','','a','','i',
	'',16,'','','V','','p',' ','S','',' ','','','','','','',' ',
	'Y','','',0,'','o','h',' ','','','`','','q','','r',' ','','',
	'','W',' ','(','',' ',']','','','W','',0,'L','(','','','q','',
	'r',' ','','','','q','','g','','q','','','',2,'','r','','q',
	'','r',' ','(','','','q','','r',24,'i',5,'',1,'','','q','','r',
	' ','g','','','\\','',0,'','g','','','`','','5','D','z',0,'h','(',
	'','F',0,' ','+','','0','7','',' ',' ','',255,'',34,'','#','',4,
	'',34,'','b','','',34,'','d','',8,'',34,'','c','','',34,'',
	'e','L','','','','','',0,' ','','','','','','',' ','(','',
	'','','','',' ','g','','','e','','b','','e','','b','','c','',
	'd','','c','','d','',0,'','f','','a','','p','','','','a',' ',
	'','','','','',0,'L','','','','','',7,'','8','','7','L','c',
	'','','',2,'',30,'L','7','',' ','',255,'','','`',' ','',255,'',
	'','`',' ','','','','','`',' ','',255,'','','`',' ','',255,'',
	'','`',' ','','',' ','','','','','H','','F','H','',15,3,'H','',
	12,3,'',13,3,'',14,3,'(','l',20,0,8,'',12,3,'',13,3,'',14,3,'h','',
	15,3,'`',' ','','','','-','','.','','+',' ','',255,'','','`','',
	1,',','',0,'',10,' ','','','',10,'','+','',',',' ','',255,'',
	'W','',10,'',23,'',28,' ','',255,')',16,'',23,'','z','',2,'',7,
	'','d','','','L',30,'','`',' ','',255,')','','',5,'',29,'L','7',
	'','','{','',2,'',14,'','-','','.','','v','','',' ',30,'','L',
	'*','',' ','','',' ','3','','L','w','',' ',25,'',' ','',255,'',
	11,'`',' ',25,'','','I',' ','',255,'','','L','','','',0,' ','',
	255,'',1,'',0,' ','',255,' ',6,'',' ','W','',' ',6,'',' ',0,'',
	'',0,'','I',' ','',255,' ',6,'',' ',0,'','','','','I','L','',
	255,' ',14,'','L','','',' ','y',0,'',2,'h','h','`',' ','','',' ',
	'y',0,'','','L',8,'','',0,' ','',255,' ',17,'',' ','','','','I',
	'','',1,'',0,' ','',255,' ',6,'',' ',0,'','','J','',0,'','I',
	'',3,'',1,'',' ','',255,' ',6,'',' ',0,'','','','','J','','I',
	' ','',255,' ',6,'',' ',14,'',' ','','',' ','','','',34,'','#',
	'L','',255,'','','','',' ','g','',' ',12,'','','','','','',
	'n',' ',7,'',' ',12,'',' ','','','',0,'','o',' ','S','','','',
	'','',' ','P','','','f','H',16,13,' ','I','','','f','0',9,'',18,
	'I',255,'',18,' ','','','','','','',' ','g','','h',16,3,' ','',
	'','','','','','L','C','',' ','','','',0,'',18,' ','k','','',
	'N','',0,' ','','','','W','',0,' ','','','',0,'','f','',18,' ',
	'','','','N','',0,'L',15,'','H','L','','','','I',15,'','','',
	'I',15,'','','',0,0,0,0,5,'','',26,'-',27,'','(',7,'','','','',
	'h','',1,'','#','5','','','','',']','','(','','I',15,'','','',
	'f','H',16,3,' ','','','','a','H','','','',7,'','','','',' ',
	15,'','','>','','',' ','C','','h','','','',7,'','','','',' ',
	'P','','h',16,3,'L','','','`',11,'v','','','','','y',30,'','',
	'','{','','','',16,'|',12,31,'g','','|','','S','','','}',20,'d',
	'p','L','}','','','Q','z','}','c','0','','~','~','','D','',':','~',
	'L','','','','','','','',19,'',0,0,0,0,' ','',255,'',0,'',19,
	' ','z','','X','','','l',0,3,'','0',3,'L',':','','L','t','',' ',
	'S','',' ','','',' ',34,'','','','','','','','z','',2,'','{',
	'','`','','',':','',10,'',' ','','','8','','0','8','','','`',
	'','O','','R','X','','L','','T','',16,3,'','H','','','',17,3,
	'',18,3,'','','','','',5,'',6,'','','','','',3,'',4,'',28,
	'','','','','s','',16,'','',3,'','S','',0,'','h','',19,'',
	24,'',1,'','',1,'','',1,'',25,'',22,'8',' ','',255,'','+','',
	',','8',' ','',255,'','7','','8','','3','','4','',0,'','','+',
	'','+','',2,'',',','`','','+','',',',' ',8,'','','s','','',' ',
	30,'','','7','8','','+','','','8','',',',' ','','','','`','',
	'',' ',30,'','L','D','','','','','','|','',26,'','','','',
	'','',11,'','G','','',0,3,'',16,'','`',0,' ','B','A','S','I','C',
	' ','B','Y','T','E','S',' ','F','R','E','E',13,0,'',13,' ',' ',' ',' ',
	'*','*','*','*',' ','C','O','M','M','O','D','O','R','E',' ','6','4',' ',
	'B','A','S','I','C',' ','V','2',' ','*','*','*','*',13,13,' ','6','4',
	'K',' ','R','A','M',' ','S','Y','S','T','E','M',' ',' ',0,'','H',' ',
	'',255,'','h','',1,'','`','','','','','','','','','','',
	'','','','','','','','','','','','','','','','','','',
	'','','',1,'','','`','','',2,'','','`','i',2,'','','','',
	4,'','','','','`',25,'&','D',25,26,17,'',13,'p',12,6,6,'',2,'7',
	1,'',0,'i',0,'',0,'','','`','','(','',25,'`','',7,'','','','',
	' ','l','','','','','','`',' ','','','',0,'','',2,'','','',
	'H','','',2,'','','','',2,'',10,'','',2,'','',2,'',14,'',
	'',2,'',4,'','',2,'',12,'','','','','','',2,9,'','','',0,
	'','','',24,'i','(','',1,'','','',26,'','','',255,'','','',
	24,' ',255,'','',16,'','',0,'','','','','','','','','','',
	'0',8,24,'i','(','','','',16,'',' ','','','',39,'','','','0',
	6,24,'i','(','',16,'','','','L','$','','','','',3,'L','','',
	'`','',' ','','','L','f','','',3,'','','',0,'','','','/','',
	'','','',255,'','','','','`','','w',2,'',0,'','x',2,'','w',
	2,'','','','','','','','','X',24,'`',' ',22,'','','','','',
	'','',2,'','','x','','','',12,'','','','',2,'',0,'','',' ',
	19,'',' ','','','','','',16,'',9,'x','','','','','','','v',
	2,'','','','','','',13,'','','','','','','','','',' ','',
	3,'','','','','','','',0,'','',2,'','','','','','','0',
	27,'','',' ','','','','','',18,'','','','','','','',10,'',
	'+','','H','','H','','','','','','','','','','',')','?',6,
	'','$','',16,2,9,'','',4,'','','',4,'p',2,9,'@','','',' ','',
	'','','','',23,'',0,'','','',13,'','','',3,'',6,'','','',
	3,'',3,' ',22,'','',13,'','','h','','h','','','','','','',
	2,'',255,24,'`','',34,'',8,'','','I',1,'','','',34,'`',9,'@','',
	'','',2,9,'','','','',2,'','','','',2,' ',19,'',' ','','',
	'h','','','','',2,'F','','h','','h',24,'X','`',' ','','','','',
	'','','','','','?','','O','','2','','',2,'',3,'L','g','','',
	'','',25,'',7,' ','','','','','','',22,'','V','','','','',
	9,'','','','','','',24,'i','(','','','','','0',3,'','','',
	'L','','','','',' ','|','','',0,'','','`','','','',6,'','',
	'h','h','','','','','',' ','l','','','','','','`','H','','',
	'','H','','H','',0,'','','','','','',16,3,'L','','','',13,
	'',3,'L','','','',' ','',16,'','`','',4,')','','',2,')','?',' ',
	'','','L','','','','','',3,'L','','','',20,'','.','','',6,
	' ',1,'','L','s','',' ','','','','','',' ','$','','','','',
	'','','','','','','','','','','','','','','',' ','','',
	'','',2,'','',16,'M','','','',3,'L','','','',18,'',2,'','',
	'',19,'',3,' ','f','','',29,'',23,'',' ','','','','','','',
	'','',9,'','',' ','|','','',0,'','','L','','','',17,'',29,
	24,'','i','(','','','','','','','','','','','','','(','',
	4,'','','','',' ','|','','L','','',' ','','','L','D','',')',
	'','','','',2,'','^','',' ','',3,'L','','','',13,'',3,'L','',
	'','','','','?','',20,'','7','','','','','',' ','',4,'','',
	'',7,'','O','','$',' ','e','','','',' ','$','','','','','',
	'','','','','','','','','','','','','','',' ','','','',
	'',2,'','','','','L','','','','','',5,9,'@','L','','','',
	17,'',22,'','','','7','','','','','8','','(','',4,'','',16,
	'*',' ','l','','','%','',18,'',4,'',0,'','','',29,'',18,'','',
	9,' ','','','','','','L','','',' ',1,'','L','','','',19,'',
	6,' ','D','','L','','',9,'',' ','','','L','O','','F','','','',
	'','',25,'',3,' ','','','','',16,'','','','L','l','','',0,
	'','','','','','','','',' ','|','','L','','','',2,'',0,'',
	'','',7,24,'i','(','','','','`','','','`','',2,'',39,'','',
	'',7,24,'i','(','','','','`','','','',25,'',2,'','','`','',
	15,'','','','',4,'',16,'','`','','',2,'`','',5,28,'','',30,
	31,'','','','','','','','','','','','H','','','H','','',
	'H','','','H','',255,'','','','','','',2,'',' ','','','',
	24,'',12,'','','','','','','',' ','','','0','',' ',255,'',
	'',0,'','',')','','','',16,2,9,'','','','','',24,'','','',
	'',9,'','','','','',16,'','','','','',2,'','','',0,'','',
	1,'','','',8,'','','',0,'','(','',11,'',0,'','','','','',
	'','','','','','','h','','','h','','','h','','','h','','',
	'`','','','','','',16,'','','',2,'',24,'',14,'',12,' ','',
	'','','',2,'','','','L','','','','','H','','','H','','',
	'H','','','H','',25,'',' ','','','','',2,'',14,'',12,'','',
	'','','','','',' ','','','0','',' ',255,'','',23,'','',2,'',
	15,'','',')','','','',16,2,9,'','','','','','','','',2,' ',
	'','','L','X','',')',3,13,'',2,'','',' ','','','',39,'','',
	'','','','','','','',16,'','`',' ','$','','','','','','',
	'',')',3,9,'','','','`','','','','','','','',')',3,13,'',2,
	'','','`','',39,' ','','',' ','$','',' ','','','',' ','','',
	'',16,'','`','','','',2,'','',' ','$','','','','','','','',
	'','','`','','','','','','',')',3,9,'','','','`',' ','',255,
	'','','',')','','','','%','',20,'','','','','F','','','',
	2,'','','',17,'','','','',' ','$','','','','','',2,'','',
	2,'','','I','',' ',28,'','',1,')',16,'',10,'',0,'','','',1,9,
	' ','',8,'','','',6,'',1,')',31,'',1,' ','','','',13,'','h',
	'','h','','h','@','',0,'','',2,'','@','','','',0,'','',1,'',
	'',255,'','a','','','','','','','','','','','','',0,'',
	'',8,'H','',1,'','',1,'','','','J','',22,'H','','','',5,'',
	12,'',3,'',8,13,'',2,'','',2,16,2,'','','h','','','A','',11,
	'','','','8','h','*','',0,'','','','h','l','',2,'','','','',
	'','','','',7,'',16,'','',2,'','6',')','',',','',2,'0',22,'p',
	'I','','','',')','',20,'',12,'',' ','',8,'',29,'',4,'',17,'',
	'5','','',2,'',5,'','',2,'','+','','',2,'','&','',4,'','',
	2,'','','',16,28,'','','','','','',2,'','',2,'',255,'',14,
	'','','','','',2,'',6,'','w',2,'','','','','','',0,'','`',
	'','',2,'',3,'',21,'','',2,'','','','',2,'0',29,'',24,'','I',
	2,'',24,'','L','v','',10,'',8,'',2,'',6,'','','y','','','',
	'','z','','','','L','','','','','','',3,'','x','',20,13,29,
	'','','','',17,'3','W','A','4','Z','S','E',1,'5','R','D','6','C','F',
	'T','X','7','Y','G','8','B','H','U','V','9','I','J','0','M','K','O','N',
	'+','P','L','-','.',':','@',',','\\','*',';',19,1,'=','^','/','1','_',
	4,'2',' ',2,'Q',3,255,'','','','','','','','','#','','','$',
	'','','',1,'%','','','&','','','','',39,'','','(','','','',
	'',')','','','0','','','','','','','','','>','[','','<','',
	'',']','',1,'=','','?','!','_',4,34,'',2,'','',255,'','','','',
	'','','','','','','','','','','',1,'','','','','','',
	'','','','','','','','','','',')','','','0','','','','',
	'','','','','>','[','','<','','',']','',1,'=','','?','','_',
	4,'','',2,'','',255,'',14,'',7,'',24,'',9,2,'',9,'','','',
	11,'',24,'',')','','',24,'','L','','','',8,'',7,'','',13,'',
	2,'0',9,'',9,'','','','','-','',2,'','',2,'L','','',255,255,
	255,255,255,255,255,255,28,23,1,'',26,19,5,255,'',18,4,30,3,6,20,24,
	31,25,7,'',2,8,21,22,18,9,10,'',13,11,15,14,255,16,12,255,255,27,0,255,
	28,255,29,255,255,31,30,255,'',6,255,5,255,255,17,255,255,0,0,0,0,0,0,
	0,0,0,0,0,0,0,0,0,0,0,'','7',0,0,0,8,0,20,15,0,0,0,0,0,0,14,6,1,2,3,4,
	0,1,2,3,4,5,6,7,'L','O','A','D',13,'R','U','N',13,0,'(','P','x','','',
	'',24,'@','h','','','',8,'0','X','','','','',' ','H','p','','',
	9,'@',',',9,' ',' ','','','H','$','',16,10,'8','f','',' ','@','',
	'F','','F','','h','','','x',' ','','','','?','',3,' ','','',
	'',0,'',9,8,'',0,'','x',' ','','',' ','','',' ','','','x',' ',
	'','',' ','','','','d',' ','','','$','',16,10,' ','','','',
	'',' ','','','','',' ','','','','',' ','','','',8,'','',
	'',0,'','',0,'','','',10,'','?','f','','',5,' ','','','',3,
	' ','','',' ','','','','','','','',0,'',')','',9,16,'',0,'',
	'','','','','',4,'',7,'','',25,'',15,'','',13,'','',13,'',
	')',2,'',10,' ','','','','','X','`','','',',','',3,' ',28,'',
	'X',24,'','J','','',' ','6','','',0,'',')','','',0,'','`','',
	'',' ','6','','x',' ','','',' ','','',' ','','',' ','','','0',
	'','X','`','$','','0',5,'8','f','','',5,'H',' ','@','','h','','',
	24,'`','x',' ','','','',0,'',9,8,'',0,'','','_',',','','?',' ',
	17,'',' ','','','','',10,'','','','',' ','','','L','','',
	'x','',0,'','',' ','','',' ','','',16,'','',1,'',7,'','',25,
	'',15,'',' ','','','',13,'','',13,'',')',2,'',7,' ','','','0',
	'',16,24,'','','',5,'',2,'L','','',' ','','',' ','','','',
	'@',' ',28,'','','','','','',8,'','','',0,'','',0,'','','',
	10,16,'','f','','',0,'','',0,'','','',10,'0','','','','','',
	' ','','','$','','P',3,' ',6,'','','','X',24,'`','',0,'',')','',
	'',0,'','`','',0,'',9,16,'',0,'','`','',0,'',')','','',0,'',
	'`','',0,'',9,' ','',0,'','`','',0,'','',0,'','','',10,'`','',
	'','','','','','','`','','','','G','0','?','F','','',0,'',
	1,'','','E','','','','','','',6,'',')',4,'','','`','',' ',
	',','',2,'',20,'0',28,'p',20,'','','',1,'','','','','',2,16,
	'','','','','','','','','','','','','','','','p','','P',
	'','','','',255,'','','','',2,'J','',7,',',1,'',16,29,'P',30,
	'',0,'','','','','','',2,'','','','',2,'','',2,'',19,'',
	'','','','','',2,'`','','@',',','',16,13,'',2,'','',2,'',1,
	'',13,'','M','',2,9,'','','',2,'',13,'','`','',9,'',' ',',',
	'',2,'',1,'','P',2,'','','`','','','','3','','','','6','0',
	13,'','','E','','','','F','','f','','`','','','','','','g',
	'','',2,10,'',1,'e','','','','','','',13,'',13,'',2,'','',
	2,'','','',2,'L',';','','','','','','L','','','','',2,'',
	'','',2,'','*','','',2,'','','','','',2,'',9,'',4,'J','',
	'','','','','',' ',',','',2,'','','0','','','','E','','',
	3,'p','',',','P','','',1,',','',4,',','','',',','',2,13,'',2,'',
	'',2,'L','~','','','','','','','','','','','',2,'J','',')',
	'',2,',',1,'',16,29,'',' ','','',2,')',2,'','',',',1,'','p','',
	'',1,'',9,2,'',1,'',',',1,'','p',7,'0','','','@','','',2,24,'`',
	' ','(','','','',2,'','','',2,'','','','',2,'','','','',
	'','','',2,'J','',30,'',16,'',14,'','','',2,'',4,'','','',
	2,'',5,'','','',' ',';','',' ',6,'','',17,'',14,'','`','','',
	'','',2,'J','','(',')',8,'','$','',2,',',1,'',16,'','',34,'',
	'',2,'J','','','',1,'',')','','',1,'','',1,'',')',4,'','',
	'','',24,'L',';','','','',2,')',18,'','',24,'`','','',2,'','',
	2,'','',2,'',11,')','','','',2,'','','','',2,'`',9,8,'','',
	2,'',0,'`','H','','',2,'',17,'','',2,')',3,'','','',16,'',13,
	'','',0,'','',2,'h','`',13,'I','/','O',' ','E','R','R','O','R',' ',
	'',13,'S','E','A','R','C','H','I','N','G','','F','O','R','',13,'P',
	'R','E','S','S',' ','P','L','A','Y',' ','O','N',' ','T','A','P','','P',
	'R','E','S','S',' ','R','E','C','O','R','D',' ','&',' ','P','L','A','Y',
	' ','O','N',' ','T','A','P','',13,'L','O','A','D','I','N','',13,'S',
	'A','V','I','N','G','',13,'V','E','R','I','F','Y','I','N','',13,'F',
	'O','U','N','D','',13,'O','K','','$','',16,13,'','','',8,')','',
	' ','',255,'','(',16,'',24,'`','','','',8,'','','',15,'x','L',
	'','','',2,'',24,'','',' ','','','','',24,'`','','','',11,
	'','','','','','','','','L','2','','',3,'',9,'','','','',
	'','','L','2','','','8','',2,'','?','','',' ','','','',22,'H',
	' ','','','',13,'',5,'','@',' ',28,'','','','','','h','`','',
	'h','','','','`',' ',13,'','',11,' ','A','','',17,'',0,'','',
	'','','','',24,'`','','','',4,'',13,24,'`','L',19,'',' ','N',
	'','','','',0,'','','','',2,')','`','','','','','H','','',
	'',3,'',4,'h','L',22,'','',4,'h','L','','','J','h','','','','H',
	'','H','','#',' ',13,'','',14,' ','d','','',14,'',2,'',0,'','',
	'','','','','','','',24,'h','','h','','','','',2,'',0,'`',
	' ',23,'','L','','',' ',15,'','',3,'L',1,'',' ',31,'','','','',
	22,'',3,'',18,'',20,'',2,'',3,'L','M','','','','','`','',3,'L',
	10,'','','',24,'`','',' ',9,'','','',16,6,' ','','','L','H','',
	' ','','','','$','',16,'','L',7,'',' ',15,'','',3,'L',1,'',' ',
	31,'','','','',3,'L',13,'','',3,'',15,'',17,'',2,'',3,'L','',
	'','','','','`','','','','',24,'`','',' ',12,'','','',16,5,
	' ','','','',3,' ','','','','$','',16,'','L',7,'',' ',20,'',
	'',2,24,'`',' ',31,'','','H','','','','P','',3,'','L','','G',
	'',2,'',29,'h',' ','','',' ','','',' ',39,'','','','',1,'',
	'','','',1,'','',0,'','','','','L','}','','','',')',15,'',
	'#',' ','','','',0,'8',' ','','',' ','d','','',4,'h','',0,'`',
	'','','','b','',11,'',5,' ','j','','L','','',' ','B','','h','',
	'','','','','',20,'','','','Y',2,'','Y',2,'','c',2,'','c',2,
	'','m',2,'','m',2,24,'`','',0,'','','','','','','0',21,'','Y',
	2,'','','`','','Y',2,'','','','c',2,'','','','m',2,'','','`',
	'',0,'','','',3,'','','',3,' ','','','','','',3,' ','','',
	'','','',0,'','','`','','','',3,'L',10,'',' ',15,'','',3,'L',
	'','','','','',10,'',3,'L','','','','','','','','Y',2,'',
	'',9,'`','','','','m',2,'','','','c',2,'','Z','',3,'','V','',
	5,' ','','','','O','',2,'',3,'L',9,'',' ','','','',3,'L',19,'',
	'','',')',15,'',31,' ',23,'','','6',' ','','','','','',10,' ',
	'','','',24,'','(','L',4,'',' ',',','','',' ','',12,'','',' ',
	'8','','',23,'',4,' ','j','','','','','','','`','',7,'',0,'',
	2,'','','','','',24,'`','','','0','','','','','','',0,'',
	'','','',' ',12,'','','',9,'',' ','','','','',16,5,'h','h',
	'L',7,'','','','',12,'',0,'','',' ','','','','','','','',
	'L','T','',' ','','','','',2,'','','',10,'','','','',2,'',
	'',4,'','',' ','J','','','',2,'','',2,')',15,'',28,10,'','',
	'',2,'',9,'','','','','','','L','@','','','','','','','',
	'','',2,'','',2,'','',2,10,' ','.',255,'','',2,'J','',9,'',1,
	'',10,'',3,' ',13,'','','',2,'','',2,'','',2,'','',2,' ',39,
	'','','','',5,'','','','','','','','',5,'','','','','',
	'8','','','L','-','','','','',13,'','',6,'',3,'','',1,'','',
	4,13,0,'','',0,'','',0,'','',2,'`','','','','','l','0',3,'',
	'','',0,'','','','','',3,'L',19,'','',3,'','','','{','','',
	'',3,'L',16,'','','',' ','','','','`','','',' ','','','','',
	' ',9,'','','',' ','','',' ',19,'','','','','','J','J','','P',
	' ',19,'','','','','',8,'','','','','','','','',' ','','',
	'','','%','','','',' ','',255,'',3,'L','3','',' ',19,'','','',
	'','J','J','','','','','','',12,'',0,'','','',8,'',16,' ',
	28,'',',','','','','','',2,'','','$','','P','',' ','','',' ',
	'B','','','y','L',4,'','J','',3,'L',19,'',' ','','','',3,'L',19,
	'',' ',23,'','','h',' ','','','','','',9,' ','','','',11,'',
	'Z','','',' ',',','','','S','','','','',')',16,'8','','J','',
	1,'',17,'',3,'','','',1,'','','','','','','','','','',4,
	'','','','','',3,'','','',1,'','','','',4,'','','',2,'',
	'','',24,'','e','','','','','e','','','','','','','','',
	'','','',' ','','',' ','J','','$',24,'','','','','`','','',
	16,30,'',12,' ','/','','','','',21,'',23,' ','/','','','','',
	12,'',0,'','',' ','',255,'','','','','','`','','I','','','',
	2,'','Y','L','+','','','','','','','',0,'','','',1,'','',
	'l','2',3,'','','',3,'L',19,'','',3,'','','','_','','a','','',
	'','','',3,'L',16,'',' ','','',' ','','','','',' ',12,'','',
	'',' ','','','',0,' ','','','','',' ','','','','',' ','',
	'',' ','','','',22,'','',' ','','',' ','',255,'',7,' ','B','',
	'',0,'8','`',' ','','','','',' ','','','$','','0',17,'','',' ',
	12,'','','',')','',9,'',' ','','',' ','','',24,'`','J','',3,
	'L',19,'',' ','','','','',' ','8','','','%',' ','','','',3,'',
	'',')',1,'',2,'',1,'',' ','j','','',18,' ','g','','',13,'','',
	')',2,'',6,'',5,' ','j','','$',24,'`','','',16,'','','Q',' ','/',
	'','L','','','',0,'','','',6,'','','',2,'','','8','','',
	'',1,'','','',26,'','','','O','',6,'','','','','','','',
	1,'','',1,'','','','','0',19,'','','',0,'','',1,'','',1,'',
	'','','',0,'','','',2,'','','`','x','','','','','','','x',
	'','','','','','','X','`','','','','','',7,8,' ','',255,'',
	'','(','`','',1,',','',2,',','',3,',','',4,',','',5,',','',6,',',
	'',7,',','',8,',','',9,'H',' ','',255,'',0,'$','','P',10,' ','/',
	'','h','H',9,'0',' ','',255,'h','8','`','','','H',' ','A','','h',
	'','','','2','',0,'','','',5,'','*','',1,'',8,'',3,'',4,'',
	4,'','','','$','',16,23,'','c',' ','/','','',5,'','',' ','',
	255,'','',21,'','','','',' ','','','',24,'','`','','',' ',
	'','','','^','','','H','','','H','','','H','','','H','','',
	'',' ','','','','','','','','','','','','','','','','',
	'','','','','','','','','','','','','','','','','',0,
	'','','','','','','',12,'','','','','','','','','','',
	'','',' ','','','','i','','',' ','k','','','h','','','h','',
	'','h','','','h','','','','`','','','','','',2,'`',' ','',
	'','','','',24,'i','','','','','','','i',0,'','','`',' ',',',
	'','',29,'',5,'','','',0,'','','','','',16,'','','','',
	'','','','','','','','','','','','',24,'`',' ','','','',
	'','','','','','`',' ','.','','',26,'',27,' ','/','',' ','',
	'',' ','.','','','','','j','L','/','','',16,'$',1,'',2,'$',1,24,
	'`',' ','.','','','','','.','','','',0,'','','','',' ','',
	'',' ',23,'','',31,'x','',0,'','','','','','','','','','',
	'','','','','',14,'',17,' ','','','',20,'','',' ','8','','',
	'l','x','','','',8,'','','',13,'','',13,'','',14,'',9,25,'',
	15,'',')','','','',2,' ','','','',17,'',')','','',17,'','',
	20,3,'','',2,'',21,3,'','',2,' ','','','',2,'','',' ','','',
	'',1,')',31,'',1,'','','',255,'',255,'','','','','','','X',
	'','',2,'',21,3,24,'',21,' ','','',' ','','','L','','',' ','',
	255,24,'',11,' ','','','8','h','h','',0,'','',2,'`','','','',
	'',10,10,24,'e','',24,'e','','','','',0,'$','','0',1,'*',6,'',
	'*',6,'','*','','',6,'','',22,'','','e','','',4,'','','m',7,
	'','',5,'','','',2,'',14,'','','',2,'',13,'',')',16,'',9,'',
	'','H','','*','H','L','C',255,'X','`','',7,'','',255,'','',6,'',
	'',7,'','','','','','','',6,'','',7,'','',25,'',15,'','',
	13,'','','',2,'','','','','','J','f','','J','f','','','',24,
	'i','<','','','','J','','','',3,'L','`','','','','0',27,'',0,
	'i','0','e','','','','',28,'','i','&','e','','','','',23,'i',
	',','e','','','','',3,'L',16,'','','','',29,'','','',25,'',
	'','',2,'','','8','',19,'','','e','','','','','','I',1,'',
	'','','+','','','','','',34,'','',2,')',1,'',5,'','',2,'',
	22,'',0,'','','','',2,'','',16,'0','0','','','',' ','','',
	'','','','','L','','','','','',7,'0',3,'','',',','','','',
	0,'','','','','',15,'','','','','','0','','',16,'','','',
	'','','','','E','','','','','','','','','','0','','F','',
	'f','','','',' ','','','L','','','','','',4,'','','',7,'',
	'','0',3,'L','','','F','','','','8','','','e','',10,'',' ','',
	'','','','','','',17,'','','','&','','','',0,'','','','',
	'',13,'','','','','','','','',9,'',0,'','','',1,'',13,'',
	'','','','','','',5,'','','','L','','',' ','','','','',
	'','',' ','','','','','',2,'','','',15,'$','',16,23,'','',
	'',12,'','','','',11,'',8,' ',28,'','',4,'',0,'','','L','',
	'','p','1','',24,'','','','','','','','','','','J','','',
	'0',3,'',24,24,'',21,')',15,'','','','','','','','@','','',
	' ','','','',0,'','','','','','','','','','','','','',
	10,'',4,' ',28,'','',0,'L','J','',' ','','','',3,'L','H','','',
	'','','','-','','','',12,'',0,'','','','','',4,'',1,'','',
	'','','','K','','=','','','','>','','','','','',1,1,'','',
	'',0,1,'','','','','L',':','','','','','','','5','','','',
	0,1,'','.','','','',1,1,'',39,'','','','','','','',11,'',
	'','',0,'','','',23,'','','','','','',7,'',16,' ',28,'','',
	9,'','','',5,'','','','','',' ','','','','C','','','','',
	'x','',1,'',13,'','',13,'','','','','0',2,'','','','','',
	8,'','','',39,'','','','#',' ','','',' ','','','',0,'','',
	'','','E','','','',' ','','',' ','','','','','','','E','',
	'',5,'',' ',' ',28,'','L','','','','','','','','','','','`',
	'',8,'','','',0,'','','','','','','','','`','','','J','',
	'`','',2,'','','',0,'',6,'','',7,'','',13,'','',25,'',15,'',
	'',1,'I',8,'',1,')',8,'`','8','f','','0','<','','','',18,'',16,
	'',1,' ','','','','/','','','','',16,')','L','W','','','','',
	9,' ','','','',29,'','','',25,' ','','','',20,'','','I',1,'',
	'','',15,'','','I',1,'','',')',1,'E','','','','L','','','F',
	'','','','','','',':',16,'',' ','','','X','','','',18,'',
	0,'','','','','','','',2,'',2,9,'','','','','',' ','','',
	'',10,'','','','','','','','','','','',0,'','','','','E',
	'','','',' ','','','','','','','I',1,'','','L','','','',
	'','',3,' ','','','','P','','','',8,'x',' ','','','','','',
	'x',' ','','','','','','','','',' ','','','','',16,'','',
	10,' ','','','X','','','','','','0',' ','','','',9,'','','',
	'','','',8,'x','',17,'',9,16,'',17,'',' ','','','','','',13,
	'',' ','','','','',2,'',9,'',21,3,'','',2,'',20,3,'(','`',' ',
	'','','','','','','','',20,3,'','','','',21,3,'`','',1,9,
	' ','',1,'`','8','','','','','','','','','`','','','',2,'',
	'','`','',255,'x','','',' ',2,'','',3,'l',0,'','',22,'',' ','',
	'',' ','P','',' ',21,'',' ','[',255,'X','l',0,'','',5,'',15,'',
	'',3,'','',3,'','','','`','','','','8','0','','0','','',24,
	'','','','','',31,'',20,3,'',2,'','','','','',20,3,'',16,
	'','`','1','','f','','G','','J','','','',14,'','P','','3','',
	'W','','','','','','>','','/','','f','','','','','','',0,
	'','',2,0,'',0,2,'',0,3,'','','','','<','',3,'','','','',
	'','',3,'','','','','','','','','U','','','','','',15,'*',
	'','','','','',8,'','','','','','','','','','','','',
	24,' ','-','','',8,'','',2,'',4,'','',2,'`','j','','','','1',
	'',',','','','','',13,'','',13,'','',0,'','',8,'',14,'','',
	14,'','',15,'','',15,'','',0,'',3,'','',3,'','',24,'','',
	'',2,'','',7,'',0,'','','?','',2,'','','','',1,'','/','',
	0,'','',2,'',10,'','%','',4,'','','@','L','','','','','',4,
	'','','B','',5,'','L','n',255,'','','','','','','`','','',
	'','','','','`','','','',2,'',13,'','',2,'H','',0,'','',2,
	'h','`','','','','',5,'','','','`','','',2,'`','',6,'','',
	2,'','',2,'','',2,'','',2,'`','',6,'','',2,'','',2,'','',
	2,'','',2,'`','x','l',24,3,'H','','H','','H','','','',13,'','',
	13,'','0',28,' ',2,'','',3,'l',2,'',' ','','',' ','',255,'',12,
	' ',21,'',' ','','',' ',24,'','l',2,'','','-','',2,'',')',1,'',
	'(','',0,'',')','',5,'','',0,'','','',2,'',13,'','',')',18,
	'',13,')',2,'',6,' ','','','L','','',' ',7,255,' ','','','L','',
	'','',')',2,'',6,' ','','','L','','','',')',16,'',3,' ',7,255,
	'','',2,'',13,'','h','','h','','h','@','',39,'>',26,'',17,'t',
	14,'',12,'E',6,'',2,'F',1,'',0,'q',0,'',1,'',')',1,'','','',6,
	'','',28,'m','',2,'',6,'','',7,'','m','',2,'',7,'','',17,'',
	15,'','','',2,'',13,'','',255,'',6,'','',7,'','L','Y','','',
	'',2,'',6,'','','',2,'',7,'','',17,'',15,'','',18,'M','',2,
	'','',2,'',255,'',6,'','',7,'','','',2,'','','`','','','',
	2,'*','','','i','','','',2,'','i',0,'','',2,'`','','',8,'h',
	')','','H','H','','H','','H','','',4,1,')',16,'',3,'l',22,3,'l',
	20,3,' ',24,'','',18,'','','','',25,'',')',1,'','',2,'L','',
	'','','','',13,'','',14,'',')','',9,17,'',14,'','L','','',
	3,'L','[',255,'L','','','L','P','','L',21,'','L',26,'','L',24,'',
	'L','','','L','','','L','%','','L','4','','L','','','L','!','',
	'L',19,'','L','','','L','','','L','','','L',12,'','L',9,'','L',
	7,'','L',0,'','L','','','l',26,3,'l',28,3,'l',30,3,'l',' ',3,'l',34,
	3,'l','$',3,'l','&',3,'L','','','L','','','L','','','L','','',
	'l','(',3,'l','*',3,'l',',',3,'L','','','L',5,'','L',10,'','L',0,'',
	'R','R','B','Y','C','','','','H',255,0
};

BYTE key_table[256][2] =
{
	{ 32, 0 },
	{ 32, 0 },
	{ 32, 0 },
	{ 32, 0 },
	{ 226, 19 },
	{ 247, 191 },
	{ 95, 1 },
	{ 0, 0 },
	{ 1, 1 },
	{ 128, 4 },
	{ 128, 59 },
	{ 64, 193 },
	{ 255, 255 },
	{ 1, 2 },
	{ 0, 0 },
	{ 0, 0 },
	{ 184, 157 },
	{ 100, 129 },
	{ 164, 200 },
	{ 247, 191 },
	{ 128, 59 },
	{ 64, 193 },
	{ 255, 255 },
	{ 255, 255 },
	{ 0, 0 },
	{ 0, 0 },
	{ 196, 157 },
	{ 100, 129 },
	{ 236, 253 },
	{ 100, 0 },
	{ 112, 222 },
	{ 64, 193 },
	{ 128, 16 },
	{ 100, 0 },
	{ 168, 86 },
	{ 249, 191 },
	{ 237, 135 },
	{ 248, 191 },
	{ 184, 157 },
	{ 100, 129 },
	{ 4, 253 },
	{ 100, 0 },
	{ 160, 139 },
	{ 100, 129 },
	{ 0, 0 },
	{ 84, 0 },
	{ 80, 158 },
	{ 100, 129 },
	{ 16, 8 },
	{ 128, 1 },
	{ 128, 8 },
	{ 2, 1 },
	{ 2, 8 },
	{ 4, 1 },
	{ 4, 8 },
	{ 8, 1 },
	{ 64, 2 },
	{ 16, 1 },
	{ 236, 252 },
	{ 100, 0 },
	{ 237, 126 },
	{ 248, 191 },
	{ 32, 253 },
	{ 100, 0 },
	{ 0, 0 },
	{ 2, 4 },
	{ 8, 16 },
	{ 4, 16 },
	{ 4, 4 },
	{ 2, 64 },
	{ 4, 32 },
	{ 8, 4 },
	{ 8, 32 },
	{ 16, 2 },
	{ 16, 4 },
	{ 16, 32 },
	{ 32, 4 },
	{ 16, 16 },
	{ 16, 128 },
	{ 16, 64 },
	{ 32, 2 },
	{ 128, 64 },
	{ 4, 2 },
	{ 2, 32 },
	{ 4, 64 },
	{ 8, 64 },
	{ 8, 128 },
	{ 2, 2 },
	{ 4, 128 },
	{ 8, 2 },
	{ 2, 16 },
	{ 2, 1 },
	{ 2, 1 },
	{ 2, 1 },
	{ 2, 1 },
	{ 2, 1 },
	{ 244, 252 },
	{ 100, 0 },
	{ 192, 7 },
	{ 0, 0 },
	{ 52, 8 },
	{ 0, 0 },
	{ 8, 0 },
	{ 118, 0 },
	{ 145, 163 },
	{ 247, 191 },
	{ 0, 0 },
	{ 102, 0 },
	{ 60, 8 },
	{ 118, 0 },
	{ 192, 7 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 12, 0 },
	{ 102, 0 },
	{ 0, 0 },
	{ 102, 0 },
	{ 8, 0 },
	{ 118, 0 },
	{ 92, 72 },
	{ 100, 129 },
	{ 0, 0 },
	{ 0, 0 },
	{ 56, 254 },
	{ 100, 0 },
	{ 215, 186 },
	{ 236, 255 },
	{ 32, 253 },
	{ 100, 0 },
	{ 4, 253 },
	{ 100, 0 },
	{ 3, 0 },
	{ 0, 0 },
	{ 4, 0 },
	{ 0, 0 },
	{ 3, 0 },
	{ 0, 128 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 20, 207 },
	{ 64, 0 },
	{ 1, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 8, 16 },
	{ 128, 255 },
	{ 31, 0 },
	{ 1, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 64, 4 },
	{ 64, 32 },
	{ 32, 128 },
	{ 32, 8 },
	{ 128, 2 },
	{ 64, 128 },
	{ 32, 64 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 8, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 119, 70 },
	{ 0, 0 },
	{ 103, 1 },
	{ 0, 0 },
	{ 103, 1 },
	{ 0, 0 },
	{ 0, 0 },
	{ 0, 0 },
	{ 92, 72 },
	{ 100, 129 },
	{ 0, 0 },
	{ 84, 0 },
	{ 80, 4 },
	{ 119, 0 },
	{ 1, 0 },
	{ 0, 0 },
	{ 240, 3 },
	{ 119, 0 },
	{ 56, 254 },
	{ 100, 0 },
	{ 20, 207 },
	{ 64, 0 },
	{ 95, 1 },
	{ 0, 0 },
	{ 18, 2 },
	{ 0, 0 },
	{ 252, 253 },
	{ 100, 0 },
	{ 103, 1 },
	{ 0, 0 },
	{ 244, 253 },
	{ 100, 0 },
	{ 216, 53 },
	{ 128, 128 }
};
